@@ -31,18 +31,36 @@
  */
 package org.lwjgl;
 
+import java.security.AccessController;
+import java.security.PrivilegedAction;
+import java.security.PrivilegedExceptionAction;
+import java.lang.UnsatisfiedLinkError;
 
 /**
  *
  * @author elias_naur <elias_naur@users.sourceforge.net>
- * @version $Revision: 3418 $
- * $Id: LinuxSysImplementation.java 3418 2010-09-28 21:11:35Z spasi $
+ * @version $Revision$
+ * $Id$
  */
 final class LinuxSysImplementation extends J2SESysImplementation {
 	private static final int JNI_VERSION = 19;
 
 	static {
-		java.awt.Toolkit.getDefaultToolkit(); // This will make sure libjawt.so is loaded
+		// Load libawt.so and libmawt.so, needed for libjawt.so
+		java.awt.Toolkit.getDefaultToolkit();
+		
+		// manually load libjawt.so into vm, needed since Java 7
+		AccessController.doPrivileged(new PrivilegedAction<Object>() {
+			public Object run() {
+				try {
+					System.loadLibrary("jawt");
+				} catch (UnsatisfiedLinkError e) {
+			        // catch and ignore an already loaded in another classloader 
+					// exception, as vm already has it loaded
+			    }
+				return null;
+			}
+		});
 	}
 
 	public int getRequiredJNIVersion() {
@@ -53,7 +71,7 @@ final class LinuxSysImplementation extends J2SESysImplementation {
 		// Linux may as well resort to pure Java hackery, as there's no Linux native way of doing it
 		// right anyway.
 
-		String[] browsers = {"xdg-open", "firefox", "mozilla", "opera", "konqueror", "nautilus", "galeon", "netscape"};
+		String[] browsers = {"sensible-browser", "xdg-open", "google-chrome", "chromium", "firefox", "iceweasel", "mozilla", "opera", "konqueror", "nautilus", "galeon", "netscape"};
 
 		for ( final String browser : browsers ) {
 			try {
