@@ -38,6 +38,7 @@ import net.java.games.input.Component.Identifier.Axis;
 import net.java.games.input.Component.Identifier.Button;
 import net.java.games.input.Event;
 import net.java.games.input.EventQueue;
+import net.java.games.input.Rumbler;
 
 /**
  * A wrapper round a JInput controller that attempts to make the interface
@@ -56,6 +57,8 @@ class JInputController implements Controller {
 	private ArrayList<Component> axes = new ArrayList<Component>();
 	/** The POVs that have been detected on the JInput controller */
 	private ArrayList<Component> pov = new ArrayList<Component>();
+	/** The rumblers exposed by the controller */
+	private Rumbler[] rumblers;
 	/** The state of the buttons last check */
 	private boolean[] buttonState;
 	/** The values that were read from the pov last check */
@@ -86,7 +89,7 @@ class JInputController implements Controller {
 	 * @param index The index this controller has been assigned to
 	 * @param target The target JInput controller this class is wrapping
 	 */
-	JInputController(int index,net.java.games.input.Controller target) {
+	JInputController(int index, net.java.games.input.Controller target) {
 		this.target = target;
 		this.index = index;
 
@@ -148,6 +151,8 @@ class JInputController implements Controller {
 			axesMax[i] = 1.0f;
 			deadZones[i] = 0.05f;
 		}
+		
+		rumblers = target.getRumblers();
 	}
 
 	/*
@@ -203,7 +208,8 @@ class JInputController implements Controller {
 				buttonState[buttonIndex] = event.getValue() != 0;
 
 				// fire button pressed event
-				Controllers.addEvent(new ControllerEvent(this,event.getNanos(),ControllerEvent.BUTTON,buttonIndex,false,false));
+				Controllers.addEvent(new ControllerEvent(this,event.getNanos(),ControllerEvent.BUTTON,buttonIndex,
+														 buttonState[buttonIndex],false,false,0,0));
 			}
 
 			// handle pov events
@@ -227,6 +233,8 @@ class JInputController implements Controller {
 				Component axis = event.getComponent();
 				int axisIndex = axes.indexOf(axis);
 				float value = axis.getPollData();
+				float xaxisValue = 0;
+				float yaxisValue = 0;
 
 				// fixed dead zone since most axis don't report it :(
 				if (Math.abs(value) < deadZones[axisIndex]) {
@@ -241,9 +249,17 @@ class JInputController implements Controller {
 
 				// normalize the value based on maximum value read in the past
 				value /= axesMax[axisIndex];
+
+				if (axisIndex == xaxis) {
+					xaxisValue = value;
+				}
+				if (axisIndex == yaxis) {
+					yaxisValue = value;
+				}
+
 				// fire event
-				Controllers.addEvent(new ControllerEvent(this,event.getNanos(),ControllerEvent.AXIS,axisIndex,
-														 axisIndex == xaxis,axisIndex == yaxis));
+				Controllers.addEvent(new ControllerEvent(this,event.getNanos(),ControllerEvent.AXIS,axisIndex,false,
+														 axisIndex == xaxis,axisIndex == yaxis,xaxisValue,yaxisValue));
 				axesValue[axisIndex] = value;
 			}
 		}
@@ -506,5 +522,16 @@ class JInputController implements Controller {
 		return 0;
 	}
 
+	public int getRumblerCount() {
+		return rumblers.length;
+	}
+	
+	public String getRumblerName(int index) {
+		return rumblers[index].getAxisName();
+	}
+	
+	public void setRumblerStrength(int index, float strength) {
+		rumblers[index].rumble(strength);
+	}
 
 }
