@@ -39,17 +39,24 @@ package org.lwjgl.opengl;
  */
 
 import java.awt.Canvas;
+import java.awt.event.FocusListener;
+import java.awt.event.FocusEvent;
+
 import java.io.BufferedReader;
 import java.io.IOException;
 import java.io.InputStreamReader;
+import java.nio.ByteOrder;
 import java.nio.ByteBuffer;
 import java.nio.FloatBuffer;
 import java.nio.IntBuffer;
+import java.lang.reflect.InvocationTargetException;
 
 import org.lwjgl.BufferUtils;
 import org.lwjgl.LWJGLException;
 import org.lwjgl.LWJGLUtil;
+import org.lwjgl.MemoryUtil;
 import org.lwjgl.opengl.XRandR.Screen;
+import org.lwjgl.opengles.EGL;
 
 import java.security.AccessController;
 import java.security.PrivilegedAction;
@@ -79,6 +86,8 @@ final class LinuxDisplay implements DisplayImplementation {
 	private static final int SetModeInsert = 0;
 	private static final int SaveSetRoot = 1;
 	private static final int SaveSetUnmap = 1;
+	
+	private static final int X_SetInputFocus = 42;
 
 	/** Window mode enum */
 	private static final int FULLSCREEN_LEGACY = 1;
@@ -120,7 +129,6 @@ final class LinuxDisplay implements DisplayImplementation {
 	private DisplayMode saved_mode;
 	private DisplayMode current_mode;
 
-	private Screen[] savedXrandrConfig;
 
 	private boolean keyboard_grabbed;
 	private boolean pointer_grabbed;
@@ -132,14 +140,42 @@ final class LinuxDisplay implements DisplayImplementation {
 	private boolean close_requested;
 	private long current_cursor;
 	private long blank_cursor;
+	private boolean mouseInside = true;
+	private boolean resizable;
+	private boolean resized;
+	
+	private int window_x;
+	private int window_y;
+	private int window_width;
+	private int window_height;
+	
 	private Canvas parent;
 	private long parent_window;
-	private boolean xembedded;
-	private boolean parent_focus;
-	private boolean mouseInside = true;
-	
+	private static boolean xembedded;
+	private long parent_proxy_focus_window;
+	private boolean parent_focused;
+	private boolean parent_focus_changed;
+	private long last_window_focus = 0;
+
 	private LinuxKeyboard keyboard;
 	private LinuxMouse mouse;
+	
+	private String wm_class;
+
+	private final FocusListener focus_listener = new FocusListener() {
+		public void focusGained(FocusEvent e) {
+			synchronized (GlobalLock.lock) {
+				parent_focused = true;
+				parent_focus_changed = true;
+			}
+		}
+		public void focusLost(FocusEvent e) {
+			synchronized (GlobalLock.lock) {
+				parent_focused = false;
+				parent_focus_changed = true;
+			}
+		}
+	};
 
 	private static ByteBuffer getCurrentGammaRamp() throws LWJGLException {
 		lockAWT();
@@ -259,7 +295,12 @@ final class LinuxDisplay implements DisplayImplementation {
 	 */
 	static void incDisplay() throws LWJGLException {
 		if (display_connection_usage_count == 0) {
-			GLContext.loadOpenGLLibrary();
+			try {
+				// TODO: Can we know if we're on desktop or ES?
+				GLContext.loadOpenGLLibrary();
+				org.lwjgl.opengles.GLContext.loadOpenGLLibrary();
+			} catch (Throwable t) {
+			}
 			saved_error_handler = setErrorHandler();
 			display = openDisplay();
 //			synchronize(display, true);
@@ -272,6 +313,8 @@ final class LinuxDisplay implements DisplayImplementation {
 	private static native void synchronize(long display, boolean synchronize);
 
 	private static int globalErrorHandler(long display, long event_ptr, long error_display, long serial, long error_code, long request_code, long minor_code) throws LWJGLException {
+		if (xembedded && request_code == X_SetInputFocus) return 0; // ignore X error in xembeded mode to fix a browser issue when dragging or switching tabs 
+		
 		if (display == getDisplay()) {
 			String error_msg = getErrorText(display, error_code);
 			throw new LWJGLException("X Error - disp: 0x" + Long.toHexString(error_display) + " serial: " + serial + " error: " + error_msg + " request_code: " + request_code + " minor_code: " + minor_code);
@@ -408,26 +451,54 @@ final class LinuxDisplay implements DisplayImplementation {
 			ungrabKeyboard();
 	}
 
-	public void createWindow(DisplayMode mode, Canvas parent, int x, int y) throws LWJGLException {
+	public void createWindow(final DrawableLWJGL drawable, DisplayMode mode, Canvas parent, int x, int y) throws LWJGLException {
 		lockAWT();
 		try {
 			incDisplay();
 			try {
+				if ( drawable instanceof DrawableGLES )
+					peer_info = new LinuxDisplayPeerInfo();
+
 				ByteBuffer handle = peer_info.lockAndGetHandle();
 				try {
 					current_window_mode = getWindowMode(Display.isFullscreen());
+					
 					// Try to enable Lecagy FullScreen Support in Compiz, else
 					// we may have trouble with stuff overlapping our fullscreen window.
 					if ( current_window_mode != WINDOWED )
 						Compiz.setLegacyFullscreenSupport(true);
+					
 					// Setting _MOTIF_WM_HINTS in fullscreen mode is problematic for certain window
 					// managers. We do not set MWM_HINTS_DECORATIONS in fullscreen mode anymore,
 					// unless org.lwjgl.opengl.Window.undecorated_fs has been specified.
 					// See native/linux/org_lwjgl_opengl_Display.c, createWindow function.
 					boolean undecorated = Display.getPrivilegedBoolean("org.lwjgl.opengl.Window.undecorated") || (current_window_mode != WINDOWED && Display.getPrivilegedBoolean("org.lwjgl.opengl.Window.undecorated_fs"));
+					
 					this.parent = parent;
 					parent_window = parent != null ? getHandle(parent) : getRootWindow(getDisplay(), getDefaultScreen());
-					current_window = nCreateWindow(getDisplay(), getDefaultScreen(), handle, mode, current_window_mode, x, y, undecorated, parent_window);
+					resizable = Display.isResizable();
+					resized = false;
+					window_x = x;
+					window_y = y;
+					window_width = mode.getWidth();
+					window_height = mode.getHeight();
+
+                                        // overwrite arguments x and y - superclass always uses 0,0 for fullscreen windows
+                                        // use the coordinates of XRandRs primary screen instead
+                                        // this is required to let the fullscreen window appear on the primary screen
+                                        if (mode.isFullscreenCapable()  && current_displaymode_extension == XRANDR) {
+                                            Screen primaryScreen = XRandR.DisplayModetoScreen(Display.getDisplayMode());
+                                            x = primaryScreen.xPos;
+                                            y = primaryScreen.yPos;
+                                        }
+
+					current_window = nCreateWindow(getDisplay(), getDefaultScreen(), handle, mode, current_window_mode, x, y, undecorated, parent_window, resizable);
+					
+					// Set the WM_CLASS hint which is needed by some WM's e.g. Gnome Shell
+					wm_class = Display.getPrivilegedString("LWJGL_WM_CLASS");
+					if (wm_class == null) wm_class = Display.getTitle();
+					setClassHint(Display.getTitle(), wm_class);
+					
 					mapRaised(getDisplay(), current_window);
 					xembedded = parent != null && isAncestorXEmbedded(parent_window);
 					blank_cursor = createBlankCursor();
@@ -440,6 +511,15 @@ final class LinuxDisplay implements DisplayImplementation {
 					grab = false;
 					minimized = false;
 					dirty = true;
+
+					if ( drawable instanceof DrawableGLES )
+						((DrawableGLES)drawable).initialize(current_window, getDisplay(), EGL.EGL_WINDOW_BIT, (org.lwjgl.opengles.PixelFormat)drawable.getPixelFormat());
+
+					if (parent != null) {
+						parent.addFocusListener(focus_listener);
+						parent_focused = parent.isFocusOwner();
+						parent_focus_changed = true;
+					}
 				} finally {
 					peer_info.unlock();
 				}
@@ -451,12 +531,20 @@ final class LinuxDisplay implements DisplayImplementation {
 			unlockAWT();
 		}
 	}
-	private static native long nCreateWindow(long display, int screen, ByteBuffer peer_info_handle, DisplayMode mode, int window_mode, int x, int y, boolean undecorated, long parent_handle) throws LWJGLException;
+	private static native long nCreateWindow(long display, int screen, ByteBuffer peer_info_handle, DisplayMode mode, int window_mode, int x, int y, boolean undecorated, long parent_handle, boolean resizable) throws LWJGLException;
 	private static native long getRootWindow(long display, int screen);
 	private static native boolean hasProperty(long display, long window, long property);
 	private static native long getParentWindow(long display, long window) throws LWJGLException;
+	private static native int getChildCount(long display, long window) throws LWJGLException;
 	private static native void mapRaised(long display, long window);
 	private static native void reparentWindow(long display, long window, long parent, int x, int y);
+	private static native long nGetInputFocus(long display) throws LWJGLException;
+	private static native void nSetInputFocus(long display, long window, long time);
+	private static native void nSetWindowSize(long display, long window, int width, int height, boolean resizable);
+	private static native int nGetX(long display, long window);
+	private static native int nGetY(long display, long window);
+	private static native int nGetWidth(long display, long window);
+	private static native int nGetHeight(long display, long window);
 
 	private static boolean isAncestorXEmbedded(long window) throws LWJGLException {
 		long xembed_atom = internAtom("_XEMBED_INFO", true);
@@ -473,7 +561,7 @@ final class LinuxDisplay implements DisplayImplementation {
 
 	private static long getHandle(Canvas parent) throws LWJGLException {
 		AWTCanvasImplementation awt_impl = AWTGLCanvas.createImplementation();
-		LinuxPeerInfo parent_peer_info = (LinuxPeerInfo)awt_impl.createPeerInfo(parent, null);
+		LinuxPeerInfo parent_peer_info = (LinuxPeerInfo)awt_impl.createPeerInfo(parent, null, null);
 		ByteBuffer parent_peer_info_handle = parent_peer_info.lockAndGetHandle();
 		try {
 			return parent_peer_info.getDrawable();
@@ -490,6 +578,9 @@ final class LinuxDisplay implements DisplayImplementation {
 	public void destroyWindow() {
 		lockAWT();
 		try {
+			if (parent != null) {
+				parent.removeFocusListener(focus_listener);
+			}
 			try {
 				setNativeCursor(null);
 			} catch (LWJGLException e) {
@@ -520,12 +611,17 @@ final class LinuxDisplay implements DisplayImplementation {
 	}
 
 	private void switchDisplayModeOnTmpDisplay(DisplayMode mode) throws LWJGLException {
-		incDisplay();
-		try {
-			nSwitchDisplayMode(getDisplay(), getDefaultScreen(), current_displaymode_extension, mode);
-		} finally {
-			decDisplay();
-		}
+                if (current_displaymode_extension == XRANDR) {
+                        // let Xrandr set the display mode
+                        XRandR.setConfiguration(false, XRandR.DisplayModetoScreen(mode));
+                } else {
+                        incDisplay();
+                        try {
+                                nSwitchDisplayMode(getDisplay(), getDefaultScreen(), current_displaymode_extension, mode);
+                        } finally {
+                                decDisplay();
+                        }
+                }
 	}
 	private static native void nSwitchDisplayMode(long display, int screen, int extension, DisplayMode mode) throws LWJGLException;
 
@@ -542,11 +638,11 @@ final class LinuxDisplay implements DisplayImplementation {
 	public void resetDisplayMode() {
 		lockAWT();
 		try {
-			if( current_displaymode_extension == XRANDR && savedXrandrConfig.length > 0 )
+			if( current_displaymode_extension == XRANDR )
 			{
 				AccessController.doPrivileged(new PrivilegedAction<Object>() {
 					public Object run() {
-						XRandR.setConfiguration( savedXrandrConfig );
+						XRandR.restoreConfiguration();
 						return null;
 					}
 				});
@@ -644,12 +740,12 @@ final class LinuxDisplay implements DisplayImplementation {
 				throw new LWJGLException("No modes available");
 			switch (current_displaymode_extension) {
 				case XRANDR:
-					savedXrandrConfig = AccessController.doPrivileged(new PrivilegedAction<Screen[]>() {
-						public Screen[] run() {
-							return XRandR.getConfiguration();
+					saved_mode = AccessController.doPrivileged(new PrivilegedAction<DisplayMode>() {
+						public DisplayMode run() {
+							XRandR.saveConfiguration();
+                                                        return XRandR.ScreentoDisplayMode(XRandR.getConfiguration());
 						}
 					});
-					saved_mode = getCurrentXRandrMode();
 					break;
 				case XF86VIDMODE:
 					saved_mode = modes[0];
@@ -686,12 +782,27 @@ final class LinuxDisplay implements DisplayImplementation {
 	public void setTitle(String title) {
 		lockAWT();
 		try {
-			nSetTitle(getDisplay(), getWindow(), title);
+			final ByteBuffer titleText = MemoryUtil.encodeUTF8(title);
+			nSetTitle(getDisplay(), getWindow(), MemoryUtil.getAddress(titleText), titleText.remaining() - 1);
 		} finally {
 			unlockAWT();
 		}
 	}
-	private static native void nSetTitle(long display, long window, String title);
+	private static native void nSetTitle(long display, long window, long title, int len);
+	
+	/** the WM_CLASS hint is needed by some WM's e.g. gnome shell */
+	private void setClassHint(String wm_name, String wm_class) {
+		lockAWT();
+		try {
+			final ByteBuffer nameText = MemoryUtil.encodeUTF8(wm_name);
+			final ByteBuffer classText = MemoryUtil.encodeUTF8(wm_class);
+			
+			nSetClassHint(getDisplay(), getWindow(), MemoryUtil.getAddress(nameText), MemoryUtil.getAddress(classText));
+		} finally {
+			unlockAWT();
+		}
+	}
+	private static native void nSetClassHint(long display, long window, long wm_name, long wm_class);
 
 	public boolean isCloseRequested() {
 		boolean result = close_requested;
@@ -713,13 +824,11 @@ final class LinuxDisplay implements DisplayImplementation {
 		return result;
 	}
 
-	public PeerInfo createPeerInfo(PixelFormat pixel_format) throws LWJGLException {
+	public PeerInfo createPeerInfo(PixelFormat pixel_format, ContextAttribs attribs) throws LWJGLException {
 		peer_info = new LinuxDisplayPeerInfo(pixel_format);
 		return peer_info;
 	}
 
-	static native void setInputFocus(long display, long window, long time);
-
 	private void relayEventToParent(LinuxEvent event_buffer, int event_mask) {
 		tmp_event_buffer.copyFrom(event_buffer);
 		tmp_event_buffer.setWindow(parent_window);
@@ -737,10 +846,10 @@ final class LinuxDisplay implements DisplayImplementation {
 				relayEventToParent(event_buffer, KeyPressMask);
 				break;
 			case LinuxEvent.ButtonPress:
-				relayEventToParent(event_buffer, KeyPressMask);
+				if (xembedded || !focused) relayEventToParent(event_buffer, KeyPressMask);
 				break;
 			case LinuxEvent.ButtonRelease:
-				relayEventToParent(event_buffer, KeyPressMask);
+				if (xembedded || !focused) relayEventToParent(event_buffer, KeyPressMask);
 				break;
 			default:
 				break;
@@ -777,6 +886,23 @@ final class LinuxDisplay implements DisplayImplementation {
 					break;
 				case LinuxEvent.Expose:
 					dirty = true;
+					break;
+				case LinuxEvent.ConfigureNotify:
+					int x = nGetX(getDisplay(), getWindow());
+					int y = nGetY(getDisplay(), getWindow());
+					
+					int width = nGetWidth(getDisplay(), getWindow());
+					int height = nGetHeight(getDisplay(), getWindow());
+					
+					window_x = x;
+					window_y = y;
+					
+					if (window_width != width || window_height != height) {
+						resized = true;
+						window_width = width;
+						window_height = height;
+					}
+					
 					break;
 				case LinuxEvent.EnterNotify:
 					mouseInside = true;
@@ -813,13 +939,29 @@ final class LinuxDisplay implements DisplayImplementation {
 	public DisplayMode[] getAvailableDisplayModes() throws LWJGLException {
 		lockAWT();
 		try {
-			incDisplay();
-			try {
-				DisplayMode[] modes = nGetAvailableDisplayModes(getDisplay(), getDefaultScreen(), current_displaymode_extension);
-				return modes;
-			} finally {
-				decDisplay();
-			}
+                        incDisplay();
+                        if (current_displaymode_extension == XRANDR) {
+                                // nGetAvailableDisplayModes cannot be trusted. Use it only for bitsPerPixel
+                                DisplayMode[] nDisplayModes = nGetAvailableDisplayModes(getDisplay(), getDefaultScreen(), current_displaymode_extension);
+                                int bpp = 24;
+                                if (nDisplayModes.length > 0) {
+                                    bpp = nDisplayModes[0].getBitsPerPixel();
+                                }
+                                // get the resolutions and frequencys from XRandR
+                                Screen[] resolutions = XRandR.getResolutions(XRandR.getScreenNames()[0]);
+                                DisplayMode[] modes = new DisplayMode[resolutions.length];
+                                for (int i = 0; i < modes.length; i++) {
+                                    modes[i] = new DisplayMode(resolutions[i].width, resolutions[i].height, bpp, resolutions[i].freq);
+                                }
+                                return modes;
+                        } else {
+                                try {
+                                        DisplayMode[] modes = nGetAvailableDisplayModes(getDisplay(), getDefaultScreen(), current_displaymode_extension);
+                                        return modes;
+                                } finally {
+                                        decDisplay();
+                                }
+                        }
 		} finally {
 			unlockAWT();
 		}
@@ -879,61 +1021,119 @@ final class LinuxDisplay implements DisplayImplementation {
 	private void checkInput() {
 		if (parent == null) return;
 
-		if (parent_focus != parent.hasFocus()) {
-			parent_focus = parent.hasFocus();
+		if (xembedded) {
+			long current_focus_window = 0;
 
-			if (parent_focus) {
-				setInputFocusUnsafe(current_window);
+			if (last_window_focus != current_focus_window || parent_focused != focused) {
+				if (isParentWindowActive(current_focus_window)) {
+					if (parent_focused) {
+						nSetInputFocus(getDisplay(), current_window, CurrentTime);
+						last_window_focus = current_window;
+						focused = true;
+					}
+					else {
+						// return focus to the parent proxy focus window
+						nSetInputFocus(getDisplay(), parent_proxy_focus_window, CurrentTime);
+						last_window_focus = parent_proxy_focus_window;
+						focused = false;
+					}
+				}
+				else {
+					last_window_focus = current_focus_window;
+					focused = false;
+				}
 			}
-			else if (xembedded) {
-				setInputFocusUnsafe(1);
-			}
-		}
-		//else if (parent_focus && !focused && !xembedded) {
-		//	setInputFocusUnsafe(current_window);
-		//}
-	}
-
-	private void setFocused(boolean got_focus, int focus_detail) {
-		if (focused == got_focus || focus_detail == NotifyDetailNone || focus_detail == NotifyPointer || focus_detail == NotifyPointerRoot)
-			return;
-		focused = got_focus;
-
-		if (focused) {
-			acquireInput();
-			if (parent != null && !xembedded) parent.setFocusable(false);
 		}
 		else {
-			releaseInput();
-			if (parent != null && !xembedded) parent.setFocusable(true);
+			if (parent_focus_changed && parent_focused) {
+				setInputFocusUnsafe(getWindow());
+				parent_focus_changed = false;
+			}
 		}
 	}
-	static native long nGetInputFocus(long display);
-
-	private static void setInputFocusUnsafe(long window) {
+	
+	private void setInputFocusUnsafe(long window) {
 		try {
-			setInputFocus(getDisplay(), window, CurrentTime);
-			sync(getDisplay(), false);
+			nSetInputFocus(getDisplay(), window, CurrentTime);
+			nSync(getDisplay(), false);
 		} catch (LWJGLException e) {
 			// Since we don't have any event timings for XSetInputFocus, a race condition might give a BadMatch, which we'll catch and ignore
 			LWJGLUtil.log("Got exception while trying to focus: " + e);
 		}
 	}
-	private static native void sync(long display, boolean throw_away_events) throws LWJGLException;
+	
+	private static native void nSync(long display, boolean throw_away_events) throws LWJGLException;
+
+	/**
+	 * This method will check if the parent window is active when running
+	 * in xembed mode. Every xembed embedder window has a focus proxy
+	 * window that recieves all the input. This method will test whether
+	 * the provided window handle is the focus proxy, if so it will get its
+	 * parent window and then test whether this is an ancestor to our
+	 * current_window. If so then parent window is active.
+	 *
+	 * @param window - the window handle to test
+	 */
+	private boolean isParentWindowActive(long window) {
+		try {
+			// parent window already active as window is current_window
+			if (window == current_window) return true;
+
+			// xembed focus proxy will have no children
+			if (getChildCount(getDisplay(), window) != 0) return false;
+
+			// get parent, will be xembed embedder window and ancestor of current_window
+			long parent_window = getParentWindow(getDisplay(), window);
+
+			// parent must not be None
+			if (parent_window == None) return false;
+
+			// scroll current_window's ancestors to find parent_window
+			long w = current_window;
+
+			while (w != None) {
+				w = getParentWindow(getDisplay(), w);
+				if (w == parent_window) {
+					parent_proxy_focus_window = window; // save focus proxy window
+					return true;
+				}
+			}
+		} catch (LWJGLException e) {
+			LWJGLUtil.log("Failed to detect if parent window is active: " + e.getMessage());
+			return true; // on failure assume still active
+		}
+
+		return false; // failed to find an active parent window
+	}
+
+	private void setFocused(boolean got_focus, int focus_detail) {
+		if (focused == got_focus || focus_detail == NotifyDetailNone || focus_detail == NotifyPointer || focus_detail == NotifyPointerRoot || xembedded)
+			return;
+		focused = got_focus;
+
+		if (focused) {
+			acquireInput();
+		}
+		else {
+			releaseInput();
+		}
+	}
 
 	private void releaseInput() {
 		if (isLegacyFullscreen() || input_released)
 			return;
+		if ( keyboard != null )
+			keyboard.releaseAll();
 		input_released = true;
 		updateInputGrab();
 		if (current_window_mode == FULLSCREEN_NETWM) {
 			nIconifyWindow(getDisplay(), getWindow(), getDefaultScreen());
 			try {
-				if( current_displaymode_extension == XRANDR && savedXrandrConfig.length > 0 )
+				if( current_displaymode_extension == XRANDR )
 				{
 					AccessController.doPrivileged(new PrivilegedAction<Object>() {
 						public Object run() {
-							XRandR.setConfiguration( savedXrandrConfig );
+							XRandR.restoreConfiguration();
 							return null;
 						}
 					});
@@ -1143,7 +1343,7 @@ final class LinuxDisplay implements DisplayImplementation {
 		return false;
 	}
 
-	public PeerInfo createPbuffer(int width, int height, PixelFormat pixel_format,
+	public PeerInfo createPbuffer(int width, int height, PixelFormat pixel_format, ContextAttribs attribs,
 			IntBuffer pixelFormatCaps,
 			IntBuffer pBufferAttribs) throws LWJGLException {
 		return new LinuxPbufferPeerInfo(width, height, pixel_format);
@@ -1160,50 +1360,58 @@ final class LinuxDisplay implements DisplayImplementation {
 	public void releaseTexImageFromPbuffer(PeerInfo handle, int buffer) {
 		throw new UnsupportedOperationException();
 	}
-
-	private static ByteBuffer convertIcon(ByteBuffer icon, int width, int height) {
-		ByteBuffer icon_rgb = BufferUtils.createByteBuffer(icon.capacity());
-		int x;
-		int y;
-		byte r,g,b;
-
-		int depth = 4;
-
-		for (y = 0; y < height; y++) {
-			for (x = 0; x < width; x++) {
-				r = icon.get((x*4)+(y*width*4));
-				g = icon.get((x*4)+(y*width*4)+1);
-				b = icon.get((x*4)+(y*width*4)+2);
-
-				icon_rgb.put((x*depth)+(y*width*depth), b); // blue
-				icon_rgb.put((x*depth)+(y*width*depth)+1, g); // green
-				icon_rgb.put((x*depth)+(y*width*depth)+2, r);
+	
+	/**
+	 * This method will convert icon bytebuffers into a single bytebuffer
+	 * as the icon format required by _NET_WM_ICON should be in a cardinal
+	 * 32 bit ARGB format i.e. all icons in a single buffer the data starting
+	 * with 32 bit width & height followed by the color data as 32bit ARGB.
+	 * 
+	 * @param icons Array of icons in RGBA format
+	 */
+	private static ByteBuffer convertIcons(ByteBuffer[] icons) {
+		
+		int bufferSize = 0;
+		
+		// calculate size of bytebuffer
+		for ( ByteBuffer icon : icons ) {
+			int size = icon.limit() / 4;
+			int dimension = (int)Math.sqrt(size);
+			if ( dimension > 0 ) {
+				bufferSize += 2 * 4; // add 32 bit width & height, 4 bytes each
+				bufferSize += dimension * dimension * 4;
 			}
 		}
-		return icon_rgb;
-	}
-
-	private static ByteBuffer convertIconMask(ByteBuffer icon, int width, int height) {
-		ByteBuffer icon_mask = BufferUtils.createByteBuffer((icon.capacity()/4)/8);
-		int x;
-		int y;
-		byte a;
-
-		int depth = 4;
-
-		for (y = 0; y < height; y++) {
-			for (x = 0; x < width; x++) {
-				a = icon.get((x*4)+(y*width*4)+3);
-
-				int mask_index = x + y*width;
-				int mask_byte_index = mask_index/8;
-				int mask_bit_index = mask_index%8;
-				byte bit = (((int)a) & 0xff) >= 127 ? (byte)1 : (byte)0;
-				byte new_byte = (byte)((icon_mask.get(mask_byte_index) | (bit<<mask_bit_index)) & 0xff);
-				icon_mask.put(mask_byte_index, new_byte);
+		
+		if (bufferSize == 0) return null;
+		
+		ByteBuffer icon_argb = BufferUtils.createByteBuffer(bufferSize);//icon.capacity()+(2*4));
+		icon_argb.order(ByteOrder.BIG_ENDIAN);
+		
+		for ( ByteBuffer icon : icons ) {
+			int size = icon.limit() / 4;
+			int dimension = (int)Math.sqrt(size);
+			
+			icon_argb.putInt(dimension); // width
+			icon_argb.putInt(dimension); // height
+			
+			for (int y = 0; y < dimension; y++) {
+				for (int x = 0; x < dimension; x++) {
+					
+					byte r = icon.get((x*4)+(y*dimension*4));
+					byte g = icon.get((x*4)+(y*dimension*4)+1);
+					byte b = icon.get((x*4)+(y*dimension*4)+2);
+					byte a = icon.get((x*4)+(y*dimension*4)+3);
+					
+					icon_argb.put(a);
+					icon_argb.put(r);
+					icon_argb.put(g);
+					icon_argb.put(b);
+				}
 			}
 		}
-		return icon_mask;
+		
+		return icon_argb;
 	}
 
 	/**
@@ -1223,17 +1431,11 @@ final class LinuxDisplay implements DisplayImplementation {
 		try {
 			incDisplay();
 			try {
-				for ( ByteBuffer icon : icons ) {
-					int size = icon.limit() / 4;
-					int dimension = (int)Math.sqrt(size);
-					if ( dimension > 0 ) {
-						ByteBuffer icon_rgb = convertIcon(icon, dimension, dimension);
-						ByteBuffer icon_mask = convertIconMask(icon, dimension, dimension);
-						nSetWindowIcon(getDisplay(), getWindow(), icon_rgb, icon_rgb.capacity(), icon_mask, icon_mask.capacity(), dimension, dimension);
-						return 1;
-					}
-				}
-				return 0;
+				// get icons as cardinal ARGB format
+				ByteBuffer icons_data = convertIcons(icons);
+				if (icons_data == null) return 0;
+				nSetWindowIcon(getDisplay(), getWindow(), icons_data, icons_data.capacity());//, icon_mask, icon_mask.capacity(), dimension, dimension);
+				return icons.length;
 			} finally {
 				decDisplay();
 			}
@@ -1245,20 +1447,50 @@ final class LinuxDisplay implements DisplayImplementation {
 		}
 	}
 
-	private static native void nSetWindowIcon(long display, long window, ByteBuffer icon_rgb, int icon_rgb_size, ByteBuffer icon_mask, int icon_mask_size, int width, int height);
+	private static native void nSetWindowIcon(long display, long window, ByteBuffer icons_data, int icons_size);
 
+	public int getX() {
+		return window_x;
+	}
+
+	public int getY() {
+		return window_y;
+	}
+	
 	public int getWidth() {
-		return Display.getDisplayMode().getWidth();
+		return window_width;
 	}
 
 	public int getHeight() {
-		return Display.getDisplayMode().getHeight();
+		return window_height;
 	}
 
 	public boolean isInsideWindow() {
 		return mouseInside;
 	}
 
+	public void setResizable(boolean resizable) {
+		if (this.resizable == resizable) {
+			return;
+		}
+		
+		this.resizable = resizable;
+		nSetWindowSize(getDisplay(), getWindow(), window_width, window_height, resizable);
+	}
+
+	public boolean wasResized() {
+		if (resized) {
+			resized = false;
+			return true;
+		}
+		
+		return false;
+	}
+
+	public float getPixelScaleFactor() {
+		return 1f;
+	}
+	
 	/**
 	 * Helper class for managing Compiz's workarounds. We need this to enable Legacy
 	 * Fullscreen Support in Compiz, else we'll have trouble with fullscreen windows
@@ -1446,4 +1678,4 @@ final class LinuxDisplay implements DisplayImplementation {
 		}
 	}
 
-}
\ No newline at end of file
+}
