@@ -39,8 +39,8 @@ import java.nio.IntBuffer;
 
 /**
  * @author elias_naur <elias_naur@users.sourceforge.net>
- * @version $Revision: 3412 $
- *          $Id: WindowsContextImplementation.java 3412 2010-09-26 23:43:24Z spasi $
+ * @version $Revision$
+ *          $Id$
  */
 final class WindowsContextImplementation implements ContextImplementation {
 
@@ -60,7 +60,7 @@ final class WindowsContextImplementation implements ContextImplementation {
 	native long getHDC(ByteBuffer peer_info_handle);
 
 	public void swapBuffers() throws LWJGLException {
-		Context current_context = Context.getCurrentContext();
+		ContextGL current_context = ContextGL.getCurrentContext();
 		if ( current_context == null )
 			throw new IllegalStateException("No context is current");
 		synchronized ( current_context ) {
