@@ -1,31 +1,31 @@
-/* 
+/*
  * Copyright (c) 2002-2008 LWJGL Project
  * All rights reserved.
- * 
+ *
  * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions are 
+ * modification, are permitted provided that the following conditions are
  * met:
- * 
- * * Redistributions of source code must retain the above copyright 
+ *
+ * * Redistributions of source code must retain the above copyright
  *   notice, this list of conditions and the following disclaimer.
  *
  * * Redistributions in binary form must reproduce the above copyright
  *   notice, this list of conditions and the following disclaimer in the
  *   documentation and/or other materials provided with the distribution.
  *
- * * Neither the name of 'LWJGL' nor the names of 
- *   its contributors may be used to endorse or promote products derived 
+ * * Neither the name of 'LWJGL' nor the names of
+ *   its contributors may be used to endorse or promote products derived
  *   from this software without specific prior written permission.
- * 
+ *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
  * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
- * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR 
- * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
- * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
- * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
+ * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
+ * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+ * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
  * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
- * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
+ * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
@@ -39,20 +39,21 @@ import org.lwjgl.LWJGLUtil;
 import org.lwjgl.input.Keyboard;
 import org.lwjgl.input.Mouse;
 import org.lwjgl.openal.AL;
-import org.lwjgl.openal.AL10;
 import org.lwjgl.opengl.Display;
-import org.lwjgl.opengl.GL11;
-import org.lwjgl.util.glu.GLU;
 import org.lwjgl.util.WaveData;
 
+import static org.lwjgl.openal.AL10.*;
+import static org.lwjgl.opengl.GL11.*;
+import static org.lwjgl.util.glu.GLU.*;
+
 /**
  * <br>
- * This test demonstrates OpenAL positioning Based on the example by Chad Armstrong 
+ * This test demonstrates OpenAL positioning Based on the example by Chad Armstrong
  * (http://www.edenwaith.com/products/pige/tutorials/openal.php)
- * 
+ *
  * @author Brian Matzon <brian@matzon.dk>
- * @version $Revision: 2983 $
- * $Id: PositionTest.java 2983 2008-04-07 18:36:09Z matzon $
+ * @version $Revision$
+ * $Id$
  */
 public class PositionTest extends BasicTest {
 
@@ -75,10 +76,10 @@ public class PositionTest extends BasicTest {
   public static final int RIGHT = 2;
 
   /** Whether the demo is done */
-  private boolean finished = false;
-  
+  private boolean finished;
+
   /** Whether in pause mode */
-  private boolean pauseMode = false;
+  private boolean pauseMode;
 
   // OpenAL stuff
   // ===================================================
@@ -160,14 +161,14 @@ public class PositionTest extends BasicTest {
     // =====================================================
     LWJGLUtil.log("Setting up OpenGL");
 
-    GL11.glViewport(0, 0, WINDOW_WIDTH, WINDOW_HEIGHT);
-    GL11.glMatrixMode(GL11.GL_PROJECTION);
-    GL11.glLoadIdentity();
-    GLU.gluPerspective(50.0f, (float) WINDOW_WIDTH / WINDOW_HEIGHT, 0.0f, 50.0f);
-    GL11.glMatrixMode(GL11.GL_MODELVIEW);
-    GL11.glLoadIdentity();
-    GL11.glTranslatef(0.0f, 0.0f, -6.6f);
-    GL11.glClearColor(0.0f, 0.0f, 0.0f, 1.0f);
+    glViewport(0, 0, WINDOW_WIDTH, WINDOW_HEIGHT);
+    glMatrixMode(GL_PROJECTION);
+    glLoadIdentity();
+    gluPerspective(50.0f, (float) WINDOW_WIDTH / WINDOW_HEIGHT, 0.0f, 50.0f);
+    glMatrixMode(GL_MODELVIEW);
+    glLoadIdentity();
+    glTranslatef(0.0f, 0.0f, -6.6f);
+    glClearColor(0.0f, 0.0f, 0.0f, 1.0f);
     glut = this.new GLUT();
 
     Display.setVSyncEnabled(true);
@@ -177,17 +178,17 @@ public class PositionTest extends BasicTest {
     // =====================================================
     LWJGLUtil.log("Setting up OpenAL");
 
-    AL10.alListener(AL10.AL_POSITION, listenerPosition);
-    AL10.alListener(AL10.AL_VELOCITY, listenerVelocity);
-    AL10.alListener(AL10.AL_ORIENTATION, listenerOrientation);
+    alListener(AL_POSITION, listenerPosition);
+    alListener(AL_VELOCITY, listenerVelocity);
+    alListener(AL_ORIENTATION, listenerOrientation);
 
     // creating buffers
     LWJGLUtil.log("Creating buffers");
-    AL10.alGenBuffers(soundBuffers);
+    alGenBuffers(soundBuffers);
     soundBuffers.rewind();
 
     // creating sources
-    AL10.alGenSources(soundSources);
+    alGenSources(soundSources);
     soundSources.rewind();
 
     // load sound files (left, center, right).wav
@@ -195,37 +196,37 @@ public class PositionTest extends BasicTest {
 
     LWJGLUtil.log("Loading left.wav");
     WaveData left = WaveData.create("left.wav");
-    AL10.alBufferData(soundBuffers.get(LEFT), left.format, left.data, left.samplerate);
-    AL10.alSourcef(soundSources.get(LEFT), AL10.AL_PITCH, 1.0f);
-    AL10.alSourcef(soundSources.get(LEFT), AL10.AL_GAIN, 1.0f);
-    AL10.alSource(soundSources.get(LEFT), AL10.AL_POSITION, leftPosition);
-    AL10.alSource(soundSources.get(LEFT), AL10.AL_VELOCITY, leftVelocity);
-    AL10.alSourcei(soundSources.get(LEFT), AL10.AL_BUFFER, soundBuffers.get(LEFT));
-    AL10.alSourcei(soundSources.get(LEFT), AL10.AL_LOOPING, AL10.AL_TRUE);
+    alBufferData(soundBuffers.get(LEFT), left.format, left.data, left.samplerate);
+    alSourcef(soundSources.get(LEFT), AL_PITCH, 1.0f);
+    alSourcef(soundSources.get(LEFT), AL_GAIN, 1.0f);
+    alSource(soundSources.get(LEFT), AL_POSITION, leftPosition);
+    alSource(soundSources.get(LEFT), AL_VELOCITY, leftVelocity);
+    alSourcei(soundSources.get(LEFT), AL_BUFFER, soundBuffers.get(LEFT));
+    alSourcei(soundSources.get(LEFT), AL_LOOPING, AL_TRUE);
 
     LWJGLUtil.log("Loading center.wav");
     WaveData center = WaveData.create("center.wav");
-    AL10.alBufferData(soundBuffers.get(CENTER), center.format, center.data, center.samplerate);
-    AL10.alSourcef(soundSources.get(CENTER), AL10.AL_PITCH, 1.0f);
-    AL10.alSourcef(soundSources.get(CENTER), AL10.AL_GAIN, 1.0f);
-    AL10.alSource(soundSources.get(CENTER), AL10.AL_POSITION, centerPosition);
-    AL10.alSource(soundSources.get(CENTER), AL10.AL_VELOCITY, centerVelocity);
-    AL10.alSourcei(soundSources.get(CENTER), AL10.AL_BUFFER, soundBuffers.get(CENTER));
-    AL10.alSourcei(soundSources.get(CENTER), AL10.AL_LOOPING, AL10.AL_TRUE);
+    alBufferData(soundBuffers.get(CENTER), center.format, center.data, center.samplerate);
+    alSourcef(soundSources.get(CENTER), AL_PITCH, 1.0f);
+    alSourcef(soundSources.get(CENTER), AL_GAIN, 1.0f);
+    alSource(soundSources.get(CENTER), AL_POSITION, centerPosition);
+    alSource(soundSources.get(CENTER), AL_VELOCITY, centerVelocity);
+    alSourcei(soundSources.get(CENTER), AL_BUFFER, soundBuffers.get(CENTER));
+    alSourcei(soundSources.get(CENTER), AL_LOOPING, AL_TRUE);
 
     LWJGLUtil.log("Loading right.wav");
     WaveData right = WaveData.create("right.wav");
-    AL10.alBufferData(soundBuffers.get(RIGHT), right.format, right.data, right.samplerate);
-    AL10.alSourcef(soundSources.get(RIGHT), AL10.AL_PITCH, 1.0f);
-    AL10.alSourcef(soundSources.get(RIGHT), AL10.AL_GAIN, 1.0f);
-    AL10.alSource(soundSources.get(RIGHT), AL10.AL_POSITION, rightPosition);
-    AL10.alSource(soundSources.get(RIGHT), AL10.AL_VELOCITY, rightVelocity);
-    AL10.alSourcei(soundSources.get(RIGHT), AL10.AL_BUFFER, soundBuffers.get(RIGHT));
-    AL10.alSourcei(soundSources.get(RIGHT), AL10.AL_LOOPING, AL10.AL_TRUE);
+    alBufferData(soundBuffers.get(RIGHT), right.format, right.data, right.samplerate);
+    alSourcef(soundSources.get(RIGHT), AL_PITCH, 1.0f);
+    alSourcef(soundSources.get(RIGHT), AL_GAIN, 1.0f);
+    alSource(soundSources.get(RIGHT), AL_POSITION, rightPosition);
+    alSource(soundSources.get(RIGHT), AL_VELOCITY, rightVelocity);
+    alSourcei(soundSources.get(RIGHT), AL_BUFFER, soundBuffers.get(RIGHT));
+    alSourcei(soundSources.get(RIGHT), AL_LOOPING, AL_TRUE);
 
     LWJGLUtil.log("Soundfiles loaded successfully");
     // -----------------------------------------------------
-    
+
     Mouse.setGrabbed(true);
   }
 
@@ -260,7 +261,7 @@ public class PositionTest extends BasicTest {
 
       // allow window to process internal messages
       Display.update();
-      
+
       // render and paint if !minimized and not dirty
       if(Display.isVisible()) {
         render();
@@ -268,10 +269,10 @@ public class PositionTest extends BasicTest {
         // sleeeeeep
         pause(100);
       }
-      
+
       // act on pause mode
       paused(!(Display.isVisible() || Display.isActive()));
-      
+
       // start sound after first paint, since we don't want
       // the delay before something is painted on the screen
       if (firstRun && !pauseMode) {
@@ -282,37 +283,37 @@ public class PositionTest extends BasicTest {
       }
     }
   }
-  
+
   /**
    * Starts playing the sounds at different times
    */
   private void startSounds() {
-    AL10.alSourcePlay(soundSources.get(LEFT));
+    alSourcePlay(soundSources.get(LEFT));
     pause(300);
-    AL10.alSourcePlay(soundSources.get(CENTER));
+    alSourcePlay(soundSources.get(CENTER));
     pause(500);
-    AL10.alSourcePlay(soundSources.get(RIGHT));    
+    alSourcePlay(soundSources.get(RIGHT));
   }
-  
+
   /**
    * Handles any changes in pause mode
-   * 
+   *
    * @param paused Which pause mode to enter
    */
   private void paused(boolean paused) {
     // if requesting pause, and not paused - pause and stop sound
     if(paused && !pauseMode) {
       pauseMode = true;
-      AL10.alSourcePause(soundSources);
+      alSourcePause(soundSources);
       System.out.println("pauseMode = true");
-    } 
-    
+    }
+
     // else go out of pause mode and start sounds
     else if(!paused && pauseMode) {
       pauseMode = false;
       startSounds();
       System.out.println("pauseMode = false");
-    }    
+    }
   }
 
   /**
@@ -330,17 +331,17 @@ public class PositionTest extends BasicTest {
     // Test for play
     // ============================================
     if (Keyboard.isKeyDown(Keyboard.KEY_1)) {
-      AL10.alSourcePlay(soundSources.get(LEFT));
+      alSourcePlay(soundSources.get(LEFT));
       LWJGLUtil.log("Playing left.wav");
     }
 
     if (Keyboard.isKeyDown(Keyboard.KEY_2)) {
-      AL10.alSourcePlay(soundSources.get(CENTER));
+      alSourcePlay(soundSources.get(CENTER));
       LWJGLUtil.log("Playing center.wav");
     }
 
     if (Keyboard.isKeyDown(Keyboard.KEY_3)) {
-      AL10.alSourcePlay(soundSources.get(RIGHT));
+      alSourcePlay(soundSources.get(RIGHT));
       LWJGLUtil.log("Playing right.wav");
     }
     // --------------------------------------------
@@ -348,17 +349,17 @@ public class PositionTest extends BasicTest {
     // Test for stop
     // ============================================
     if (Keyboard.isKeyDown(Keyboard.KEY_4)) {
-      AL10.alSourceStop(soundSources.get(LEFT));
+      alSourceStop(soundSources.get(LEFT));
       LWJGLUtil.log("Stopped left.wav");
     }
 
     if (Keyboard.isKeyDown(Keyboard.KEY_5)) {
-      AL10.alSourceStop(soundSources.get(CENTER));
+      alSourceStop(soundSources.get(CENTER));
       LWJGLUtil.log("Stopped center.wav");
     }
 
     if (Keyboard.isKeyDown(Keyboard.KEY_6)) {
-      AL10.alSourceStop(soundSources.get(RIGHT));
+      alSourceStop(soundSources.get(RIGHT));
       LWJGLUtil.log("Stopped right.wav");
     }
     // --------------------------------------------
@@ -367,12 +368,12 @@ public class PositionTest extends BasicTest {
     // ============================================
     if (Keyboard.isKeyDown(Keyboard.KEY_LEFT)) {
       listenerPosition.put(0, listenerPosition.get(0) - 0.1f);
-      AL10.alListener(AL10.AL_POSITION, listenerPosition);
+      alListener(AL_POSITION, listenerPosition);
     }
 
     if (Keyboard.isKeyDown(Keyboard.KEY_RIGHT)) {
       listenerPosition.put(0, listenerPosition.get(0) + 0.1f);
-      AL10.alListener(AL10.AL_POSITION, listenerPosition);
+      alListener(AL_POSITION, listenerPosition);
     }
 
     if (Keyboard.isKeyDown(Keyboard.KEY_UP)) {
@@ -381,7 +382,7 @@ public class PositionTest extends BasicTest {
       } else {
         listenerPosition.put(2, listenerPosition.get(2) - 0.1f);
       }
-      AL10.alListener(AL10.AL_POSITION, listenerPosition);
+      alListener(AL_POSITION, listenerPosition);
     }
 
     if (Keyboard.isKeyDown(Keyboard.KEY_DOWN)) {
@@ -390,10 +391,10 @@ public class PositionTest extends BasicTest {
       } else {
         listenerPosition.put(2, listenerPosition.get(2) + 0.1f);
       }
-      AL10.alListener(AL10.AL_POSITION, listenerPosition);
+      alListener(AL_POSITION, listenerPosition);
     }
     // --------------------------------------------
-    
+
     // Test for movement with Mouse
     // ============================================
     listenerPosition.put(0, listenerPosition.get(0) + (0.01f * Mouse.getDX()));
@@ -404,9 +405,9 @@ public class PositionTest extends BasicTest {
     if (Mouse.isButtonDown(1)) {
       listenerPosition.put(2, listenerPosition.get(2) + 0.1f);
     }
-    
-    AL10.alListener(AL10.AL_POSITION, listenerPosition);
-    
+
+    alListener(AL_POSITION, listenerPosition);
+
     // empty mouse buffer
     while(Mouse.next());
   }
@@ -415,48 +416,48 @@ public class PositionTest extends BasicTest {
    * Render the scene
    */
   private void render() {
-    GL11.glClear(GL11.GL_COLOR_BUFFER_BIT | GL11.GL_DEPTH_BUFFER_BIT);
-    GL11.glPushMatrix();
+    glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
+    glPushMatrix();
     {
-      GL11.glRotatef(20.0f, 1.0f, 1.0f, 0.0f);
+      glRotatef(20.0f, 1.0f, 1.0f, 0.0f);
 
       // left
-      GL11.glPushMatrix();
+      glPushMatrix();
       {
-        GL11.glTranslatef(leftPosition.get(0), leftPosition.get(1), leftPosition.get(2));
-        GL11.glColor3f(1.0f, 0.0f, 0.0f);
+        glTranslatef(leftPosition.get(0), leftPosition.get(1), leftPosition.get(2));
+        glColor3f(1.0f, 0.0f, 0.0f);
         glut.glutWireCube(0.5f);
       }
-      GL11.glPopMatrix();
+      glPopMatrix();
 
       // center
-      GL11.glPushMatrix();
+      glPushMatrix();
       {
-        GL11.glTranslatef(centerPosition.get(0), centerPosition.get(1), centerPosition.get(2));
-        GL11.glColor3f(0.0f, 0.0f, 1.0f);
+        glTranslatef(centerPosition.get(0), centerPosition.get(1), centerPosition.get(2));
+        glColor3f(0.0f, 0.0f, 1.0f);
         glut.glutWireCube(0.5f);
       }
-      GL11.glPopMatrix();
+      glPopMatrix();
 
       // right
-      GL11.glPushMatrix();
+      glPushMatrix();
       {
-        GL11.glTranslatef(rightPosition.get(0), rightPosition.get(1), rightPosition.get(2));
-        GL11.glColor3f(0.0f, 1.0f, 0.0f);
+        glTranslatef(rightPosition.get(0), rightPosition.get(1), rightPosition.get(2));
+        glColor3f(0.0f, 1.0f, 0.0f);
         glut.glutWireCube(0.5f);
       }
-      GL11.glPopMatrix();
+      glPopMatrix();
 
       // listener
-      GL11.glPushMatrix();
+      glPushMatrix();
       {
-        GL11.glTranslatef(listenerPosition.get(0), listenerPosition.get(1), listenerPosition.get(2));
-        GL11.glColor3f(1.0f, 1.0f, 1.0f);
+        glTranslatef(listenerPosition.get(0), listenerPosition.get(1), listenerPosition.get(2));
+        glColor3f(1.0f, 1.0f, 1.0f);
         glut.glutSolidCube(0.5f);
       }
-      GL11.glPopMatrix();
+      glPopMatrix();
     }
-    GL11.glPopMatrix();
+    glPopMatrix();
   }
 
   /**
@@ -464,9 +465,9 @@ public class PositionTest extends BasicTest {
    */
   private void shutdown() {
     LWJGLUtil.log("Shutting down OpenAL");
-    AL10.alSourceStop(soundSources);
-    AL10.alDeleteSources(soundSources);
-    AL10.alDeleteBuffers(soundBuffers);
+    alSourceStop(soundSources);
+    alDeleteSources(soundSources);
+    alDeleteBuffers(soundBuffers);
     AL.destroy();
 
     LWJGLUtil.log("Shutting down Window");
@@ -475,7 +476,7 @@ public class PositionTest extends BasicTest {
 
   /**
    * main entry point
-   * 
+   *
    * @param args
    *          String array containing arguments
    */
@@ -487,7 +488,7 @@ public class PositionTest extends BasicTest {
 
   /**
    * Minute implementation of GLUT: <br>COPYRIGHT:
-   * 
+   *
    * The OpenGL Utility Toolkit distribution for Win32 (Windows NT & Windows
    * 95) contains source code modified from the original source code for GLUT
    * version 3.3 which was developed by Mark J. Kilgard. The original source
@@ -496,7 +497,7 @@ public class PositionTest extends BasicTest {
    * freely distributable without licensing fees. It is provided without
    * guarantee or warrantee expressed or implied. It was ported with the
    * permission of Mark J. Kilgard by Nate Robins.
-   * 
+   *
    * THIS SOURCE CODE IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
    * EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
    * OR MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
@@ -521,11 +522,11 @@ public class PositionTest extends BasicTest {
     float v[][] = new float[8][3];
 
     public void glutWireCube(float size) {
-      drawBox(size, GL11.GL_LINE_LOOP);
+      drawBox(size, GL_LINE_LOOP);
     }
 
     public void glutSolidCube(float size) {
-      drawBox(size, GL11.GL_QUADS);
+      drawBox(size, GL_QUADS);
     }
 
     private void drawBox(float size, int type) {
@@ -538,13 +539,13 @@ public class PositionTest extends BasicTest {
       v[1][2] = v[2][2] = v[5][2] = v[6][2] = size / 2;
 
       for (int i = 5; i >= 0; i--) {
-        GL11.glBegin(type);
-        GL11.glNormal3f(n[i][0], n[i][1], n[i][2]);
-        GL11.glVertex3f(v[faces[i][0]][0], v[faces[i][0]][1], v[faces[i][0]][2]);
-        GL11.glVertex3f(v[faces[i][1]][0], v[faces[i][1]][1], v[faces[i][1]][2]);
-        GL11.glVertex3f(v[faces[i][2]][0], v[faces[i][2]][1], v[faces[i][2]][2]);
-        GL11.glVertex3f(v[faces[i][3]][0], v[faces[i][3]][1], v[faces[i][3]][2]);
-        GL11.glEnd();
+        glBegin(type);
+        glNormal3f(n[i][0], n[i][1], n[i][2]);
+        glVertex3f(v[faces[i][0]][0], v[faces[i][0]][1], v[faces[i][0]][2]);
+        glVertex3f(v[faces[i][1]][0], v[faces[i][1]][1], v[faces[i][1]][2]);
+        glVertex3f(v[faces[i][2]][0], v[faces[i][2]][1], v[faces[i][2]][2]);
+        glVertex3f(v[faces[i][3]][0], v[faces[i][3]][1], v[faces[i][3]][2]);
+        glEnd();
       }
 
     }
