@@ -37,6 +37,9 @@ import org.lwjgl.opengl.*;
 import java.util.StringTokenizer;
 import java.util.regex.Pattern;
 
+import static org.lwjgl.opengl.GL11.*;
+import static org.lwjgl.opengl.GL32.*;
+
 /**
  * Tests the ARB_create_context extension through the use of the ContextAttribs class.
  *
@@ -71,16 +74,26 @@ public final class VersionTest {
 
 		if ( 2 < args.length ) {
 			for ( int i = 2; i < args.length; i++ ) {
-				if ( Pattern.matches("[0-9]+", args[i]) )
-					ca = ca.withLayer(Integer.parseInt(args[i]));
+				if ( "core".equalsIgnoreCase(args[i]) )
+					ca = ca.withProfileCore(true);
+				else if ( "compatibility".equalsIgnoreCase(args[i]) )
+					ca = ca.withProfileCompatibility(true);
+				else if ( "es".equalsIgnoreCase(args[i]) )
+					ca = ca.withProfileES(true);
 				else if ( "debug".equalsIgnoreCase(args[i]) )
 					ca = ca.withDebug(true);
 				else if ( "fc".equalsIgnoreCase(args[i]) )
 					ca = ca.withForwardCompatible(true);
-				else if ( "core".equalsIgnoreCase(args[i]) )
-					ca = ca.withProfileCore(true);
-				else if ( "compatibility".equalsIgnoreCase(args[i]) )
-					ca = ca.withProfileCompatibility(true);
+				else if ( "robust".equalsIgnoreCase(args[i]) )
+					ca = ca.withRobustAccess(true);
+				else if ( "reset_isolation".equalsIgnoreCase(args[i]) )
+					ca = ca.withContextResetIsolation(true);
+				else if ( "reset_lose".equalsIgnoreCase(args[i]) )
+					ca = ca.withResetNotificationStrategy(ContextAttribs.LOSE_CONTEXT_ON_RESET_ARB);
+				else if ( "release_none".equalsIgnoreCase(args[i]) )
+					ca = ca.withContextReleaseBehavior(ContextAttribs.CONTEXT_RELEASE_BEHAVIOR_NONE_ARB);
+				else if ( Pattern.matches("[0-9]+", args[i]) )
+					ca = ca.withLayer(Integer.parseInt(args[i]));
 				else
 					argsError("Unknown argument: \'" + args[i] + "\'");
 			}
@@ -110,11 +123,12 @@ public final class VersionTest {
 
 		System.out.println("Requested " + ca);
 
-		final String version = GL11.glGetString(GL11.GL_VERSION);
+		final String version = glGetString(GL_VERSION);
 
 		boolean deprecated = false;
 		try {
-			GL11.glVertex3f(0.0f, 0.0f, 0.0f);
+			glVertex3f(0.0f, 0.0f, 0.0f);
+			Util.checkGLError();
 			deprecated = true;
 		} catch (Throwable t) {}
 
@@ -127,10 +141,10 @@ public final class VersionTest {
 		final boolean coreProfile;
 
 		if ( 3 < majorVersion || (majorVersion == 3 && 2 <= minorVersion) ) {
-			final int profileMask = GL11.glGetInteger(GL32.GL_CONTEXT_PROFILE_MASK);
+			final int profileMask = glGetInteger(GL_CONTEXT_PROFILE_MASK);
 
-			compatibilityProfile = (profileMask & GL32.GL_CONTEXT_COMPATIBILITY_PROFILE_BIT) != 0;
-			coreProfile = (profileMask & GL32.GL_CONTEXT_CORE_PROFILE_BIT) != 0;
+			compatibilityProfile = (profileMask & GL_CONTEXT_COMPATIBILITY_PROFILE_BIT) != 0;
+			coreProfile = (profileMask & GL_CONTEXT_CORE_PROFILE_BIT) != 0;
 		} else {
 			compatibilityProfile = false;
 			coreProfile = false;
@@ -213,8 +227,7 @@ public final class VersionTest {
 	private static DisplayMode chooseMode(DisplayMode[] modes, int width, int height) {
 		DisplayMode bestMode = null;
 
-		for ( int i = 0; i < modes.length; i++ ) {
-			DisplayMode mode = modes[i];
+		for ( DisplayMode mode : modes ) {
 			if ( mode.getWidth() == width && mode.getHeight() == height && mode.getFrequency() <= 85 ) {
 				if ( bestMode == null || (mode.getBitsPerPixel() >= bestMode.getBitsPerPixel() && mode.getFrequency() > bestMode.getFrequency()) )
 					bestMode = mode;
@@ -231,14 +244,19 @@ public final class VersionTest {
 
 	private static void argsError(final String msg) {
 		System.out.println("\nInvalid arguments error: " + msg);
-		System.out.println("\nUsage: VersionTest <majorVersion> <minorVersion> {'core'|'compatibility', <layer>, 'debug', 'fc'}:\n");
-		System.out.println("majorVersion\t- Major OpenGL version.");
-		System.out.println("majorVersion\t- Minor OpenGL version.");
+		System.out.println("\nUsage: VersionTest <majorVersion> <minorVersion> {'core'|'compatibility'|'es', 'debug', 'fc', 'robust', 'reset_isolation', 'reset_lose', 'release_none', <layer>}:\n");
+		System.out.println("<majorVersion>\t- Major OpenGL version.");
+		System.out.println("<majorVersion>\t- Minor OpenGL version.");
 		System.out.println("core\t- Sets the Core Profile bit (optional, requires 3.2+).");
 		System.out.println("compatibility\t- Sets the Compatibility Profile bit (optional, requires 3.2+).");
-		System.out.println("layer\t- Layer plane (optional).");
+		System.out.println("es\t- Sets the OpenGL ES Profile bit (optional, requires 2.0).");
 		System.out.println("debug\t- Enables debug mode (optional).");
 		System.out.println("fc\t- Enables forward compatibility mode (optional, requires 3.0+).");
+		System.out.println("robust\t- Enables robust access (optional).");
+		System.out.println("reset_isolation\t- Enables reset isolation (optional).");
+		System.out.println("reset_lose\t- Enables lose context on reset (optional).");
+		System.out.println("release_none\t- Enables release behavior = none (optional).");
+		System.out.println("<layer>\t- Layer plane (optional).");
 
 		cleanup();
 		System.exit(-1);
