@@ -137,7 +137,7 @@ public final class ShadersTest {
 
 			System.out.println("Setting display mode to: " + displayMode);
 			Display.setDisplayMode(displayMode);
-			Display.create(new PixelFormat(8, 24, 0), "UNI".equalsIgnoreCase(args[0]) ? new ContextAttribs(3, 1) : null);
+			Display.create(new PixelFormat(8, 24, 0));
 			ShadersTest.displayMode = displayMode;
 		} catch (LWJGLException e) {
 			kill(e.getMessage());
