@@ -46,13 +46,15 @@ import javax.sound.sampled.AudioSystem;
 
 import org.lwjgl.openal.AL10;
 
+import com.sun.media.sound.WaveFileReader;
+
 /**
  *
  * Utitlity class for loading wavefiles.
  *
  * @author Brian Matzon <brian@matzon.dk>
- * @version $Revision: 3336 $
- * $Id: WaveData.java 3336 2010-04-26 21:52:59Z matzon $
+ * @version $Revision$
+ * $Id$
  */
 public class WaveData {
 	/** actual wave data */
@@ -92,9 +94,11 @@ public class WaveData {
 	 */
 	public static WaveData create(URL path) {
 		try {
-			return create(
-				AudioSystem.getAudioInputStream(
-					new BufferedInputStream(path.openStream())));
+			// due to an issue with AudioSystem.getAudioInputStream
+			// and mixing unsigned and signed code
+			// we will use the reader directly
+			WaveFileReader wfr = new WaveFileReader();
+			return create(wfr.getAudioInputStream(new BufferedInputStream(path.openStream())));
 		} catch (Exception e) {
 			org.lwjgl.LWJGLUtil.log("Unable to create from: " + path + ", " + e.getMessage());
 			return null;
@@ -214,7 +218,7 @@ public class WaveData {
 				&& total < buf.length) {
 				total += read;
 			}
-			buffer = convertAudioBytes(buf, audioformat.getSampleSizeInBits() == 16);
+			buffer = convertAudioBytes(buf, audioformat.getSampleSizeInBits() == 16, audioformat.isBigEndian() ? ByteOrder.BIG_ENDIAN : ByteOrder.LITTLE_ENDIAN);
 		} catch (IOException ioe) {
 			return null;
 		}
@@ -233,11 +237,11 @@ public class WaveData {
 		return wavedata;
 	}
 
-	private static ByteBuffer convertAudioBytes(byte[] audio_bytes, boolean two_bytes_data) {
+	private static ByteBuffer convertAudioBytes(byte[] audio_bytes, boolean two_bytes_data, ByteOrder order) {
 		ByteBuffer dest = ByteBuffer.allocateDirect(audio_bytes.length);
 		dest.order(ByteOrder.nativeOrder());
 		ByteBuffer src = ByteBuffer.wrap(audio_bytes);
-		src.order(ByteOrder.LITTLE_ENDIAN);
+		src.order(order);
 		if (two_bytes_data) {
 			ShortBuffer dest_short = dest.asShortBuffer();
 			ShortBuffer src_short = src.asShortBuffer();
