@@ -32,60 +32,71 @@
 
 package org.lwjgl.util.generator;
 
-import com.sun.mirror.type.*;
-import com.sun.mirror.util.*;
+import org.lwjgl.PointerBuffer;
+
+import java.nio.Buffer;
+import javax.lang.model.type.ArrayType;
+import javax.lang.model.type.DeclaredType;
+import javax.lang.model.type.NoType;
+import javax.lang.model.type.PrimitiveType;
+import javax.lang.model.util.SimpleTypeVisitor6;
 
 /**
- *
  * A TypeVisitor that translates TypeMirrors to JNI
  * type strings.
  *
  * @author elias_naur <elias_naur@users.sourceforge.net>
- * @version $Revision: 3412 $
- * $Id: JNITypeTranslator.java 3412 2010-09-26 23:43:24Z spasi $
+ * @version $Revision$
+ *          $Id$
  */
-public class JNITypeTranslator implements TypeVisitor {
+public class JNITypeTranslator extends SimpleTypeVisitor6<Void, Void> {
+
 	private final StringBuilder signature = new StringBuilder();
 
+	private boolean objectReturn;
+
 	public String getSignature() {
 		return signature.toString();
 	}
 
-	public void visitAnnotationType(AnnotationType t) {
-		throw new RuntimeException(t + " is not allowed");
+	public String getReturnSignature() {
+		return objectReturn ? "jobject" : signature.toString();
 	}
 
-	public void visitArrayType(ArrayType t) {
+	@Override
+	public Void visitArray(ArrayType t, Void o) {
 		final String className = t.getComponentType().toString();
 		if ( "java.lang.CharSequence".equals(className) )
-			signature.append("jobject");
+			signature.append("jlong");
 		else if ( "java.nio.ByteBuffer".equals(className) )
 			signature.append("jobjectArray");
 		else if ( "org.lwjgl.opencl.CLMem".equals(className) )
 			signature.append("jobjectArray");
 		else
 			throw new RuntimeException(t + " is not allowed");
+		return DEFAULT_VALUE;
 	}
 
-	public void visitClassType(ClassType t) {
-		signature.append("jobject");
+	private void visitClassType(DeclaredType t) {
+		final Class<?> type = Utils.getJavaType(t);
+		if ( Buffer.class.isAssignableFrom(type) || PointerBuffer.class.isAssignableFrom(type) ) {
+			signature.append("jlong");
+			objectReturn = true;
+		} else
+			signature.append("jobject");
 	}
 
-	public void visitDeclaredType(DeclaredType t) {
-		throw new RuntimeException(t + " is not allowed");
+	@Override
+	public Void visitDeclared(DeclaredType t, Void o) {
+		if ( t.asElement().getKind().isClass() )
+			visitClassType(t);
+		return DEFAULT_VALUE;
 	}
 
-	public void visitEnumType(EnumType t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
-
-	public void visitInterfaceType(InterfaceType t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
-
-	public void visitPrimitiveType(PrimitiveType t) {
+	@Override
+	public Void visitPrimitive(PrimitiveType t, Void o) {
 		String type;
-		switch (t.getKind()) {
+		switch ( t.getKind() ) {
 			case LONG:
 				type = "jlong";
 				break;
@@ -111,25 +122,13 @@ public class JNITypeTranslator implements TypeVisitor {
 				throw new RuntimeException(t + " is not allowed");
 		}
 		signature.append(type);
+		return DEFAULT_VALUE;
 	}
 
-	public void visitReferenceType(ReferenceType t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
-
-	public void visitTypeMirror(TypeMirror t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
-
-	public void visitTypeVariable(TypeVariable t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
-
-	public void visitVoidType(VoidType t) {
+	@Override
+	public Void visitNoType(NoType t, Void o) {
 		signature.append(t.toString());
+		return DEFAULT_VALUE;
 	}
 
-	public void visitWildcardType(WildcardType t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
 }
