@@ -29,54 +29,50 @@
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
-
 package org.lwjgl.util.generator;
 
-import org.lwjgl.opencl.CLMem;
-
 import java.nio.ByteBuffer;
-
-import com.sun.mirror.type.*;
-import com.sun.mirror.util.*;
+import javax.lang.model.type.*;
+import javax.lang.model.util.SimpleTypeVisitor6;
 
 /**
- * A TypeVisitor that translates (annotated) TypeMirrors to
- * java types (represented by a Class)
+ * A TypeVisitor that translates (annotated) TypeMirrors to java types
+ * (represented by a Class)
  *
  * @author elias_naur <elias_naur@users.sourceforge.net>
- * @version $Revision: 3430 $
- * $Id: JavaTypeTranslator.java 3430 2010-10-04 17:04:46Z spasi $
+ * @version $Revision$ $Id$
  */
-public class JavaTypeTranslator implements TypeVisitor {
+public class JavaTypeTranslator extends SimpleTypeVisitor6<Void, Void> {
+
 	private Class type;
 
 	public Class getType() {
 		return type;
 	}
 
-	public void visitAnnotationType(AnnotationType t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
-
-	public void visitArrayType(ArrayType t) {
+	@Override
+	public Void visitArray(ArrayType t, Void o) {
 		final TypeMirror componentType = t.getComponentType();
-		if ( componentType instanceof PrimitiveType ) {
-			type = getPrimitiveArrayClassFromKind(((PrimitiveType)componentType).getKind());
-		} else {
-			try {
-				final Class c = Class.forName(t.getComponentType().toString());
-				if ( CharSequence.class.isAssignableFrom(c) || ByteBuffer.class.isAssignableFrom(c) || org.lwjgl.PointerWrapper.class.isAssignableFrom(c) )
-					type = Class.forName("[L" + t.getComponentType() + ";");
-				else {
+		try {
+			final Class c = Class.forName(t.getComponentType().toString());
+			if ( CharSequence.class.isAssignableFrom(c) || ByteBuffer.class.isAssignableFrom(c) || org.lwjgl.PointerWrapper.class.isAssignableFrom(c) ) {
+				type = Class.forName("[L" + t.getComponentType() + ";");
+			}
+		} catch (ClassNotFoundException ex) {
+			type = null;
+		} finally {
+			if ( type == null ) {
+				if ( componentType instanceof PrimitiveType ) {
+					type = getPrimitiveArrayClassFromKind(componentType.getKind());
+				} else {
 					throw new RuntimeException(t + " is not allowed");
 				}
-			} catch (ClassNotFoundException e) {
-				throw new RuntimeException(e);
 			}
+			return DEFAULT_VALUE;
 		}
 	}
 
-	public static Class getPrimitiveClassFromKind(PrimitiveType.Kind kind) {
+	public static Class getPrimitiveClassFromKind(TypeKind kind) {
 		switch ( kind ) {
 			case LONG:
 				return long.class;
@@ -97,7 +93,7 @@ public class JavaTypeTranslator implements TypeVisitor {
 		}
 	}
 
-	private static Class getPrimitiveArrayClassFromKind(PrimitiveType.Kind kind) {
+	private static Class getPrimitiveArrayClassFromKind(TypeKind kind) {
 		switch ( kind ) {
 			case LONG:
 				return long[].class;
@@ -118,43 +114,36 @@ public class JavaTypeTranslator implements TypeVisitor {
 		}
 	}
 
-	public void visitPrimitiveType(PrimitiveType t) {
+	@Override
+	public Void visitPrimitive(PrimitiveType t, Void p) {
 		type = getPrimitiveClassFromKind(t.getKind());
+		return DEFAULT_VALUE;
 	}
 
-	public void visitDeclaredType(DeclaredType t) {
-		throw new RuntimeException(t + " is not allowed");
+	@Override
+	public Void visitDeclared(DeclaredType t, Void o) {
+		if ( t.asElement().getKind().isClass() ) {
+			visitClassType(t);
+		} else if ( t.asElement().getKind().isInterface() ) {
+			visitInterfaceType(t);
+		} else {
+			throw new RuntimeException(t.asElement().getKind() + " is not allowed");
+		}
+		return DEFAULT_VALUE;
 	}
 
-	public void visitEnumType(EnumType t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
-
-	public void visitClassType(ClassType t) {
+	private void visitClassType(DeclaredType t) {
 		type = NativeTypeTranslator.getClassFromType(t);
 	}
 
-	public void visitInterfaceType(InterfaceType t) {
+	private void visitInterfaceType(DeclaredType t) {
 		type = NativeTypeTranslator.getClassFromType(t);
 	}
 
-	public void visitReferenceType(ReferenceType t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
-
-	public void visitTypeMirror(TypeMirror t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
-
-	public void visitTypeVariable(TypeVariable t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
-
-	public void visitVoidType(VoidType t) {
+	@Override
+	public Void visitNoType(NoType t, Void p) {
 		type = void.class;
+		return DEFAULT_VALUE;
 	}
 
-	public void visitWildcardType(WildcardType t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
 }
