@@ -29,48 +29,44 @@
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
-
 package org.lwjgl.util.generator;
 
 /**
  *
- * A TypeVisitor that translates types (and optional native type
- * annotations) to the native type string.
+ * A TypeVisitor that translates types (and optional native type annotations) to
+ * the native type string.
  *
  * @author elias_naur <elias_naur@users.sourceforge.net>
- * @version $Revision: 3412 $
- * $Id: NativeTypeTranslator.java 3412 2010-09-26 23:43:24Z spasi $
+ * @version $Revision$ $Id$
  */
-
 import org.lwjgl.PointerBuffer;
 
 import java.lang.annotation.Annotation;
 import java.nio.*;
 import java.util.ArrayList;
 import java.util.Collection;
-
-import com.sun.mirror.declaration.AnnotationMirror;
-import com.sun.mirror.declaration.Declaration;
-import com.sun.mirror.type.*;
-import com.sun.mirror.util.TypeVisitor;
+import java.util.List;
+import javax.lang.model.element.AnnotationMirror;
+import javax.lang.model.element.Element;
+import javax.lang.model.type.*;
+import javax.lang.model.util.SimpleTypeVisitor6;
 
 /**
- * $Id: NativeTypeTranslator.java 3412 2010-09-26 23:43:24Z spasi $
+ * $Id$
  * <p/>
- * A TypeVisitor that translates (annotated) TypeMirrors to
- * native types
+ * A TypeVisitor that translates (annotated) TypeMirrors to native types
  *
  * @author elias_naur <elias_naur@users.sourceforge.net>
- * @version $Revision: 3412 $
+ * @version $Revision$
  */
-public class NativeTypeTranslator implements TypeVisitor {
+public class NativeTypeTranslator extends SimpleTypeVisitor6<Void, Void> {
 
-	private Collection<Class> native_types;
-	private boolean is_indirect;
-	private final Declaration declaration;
-	private final TypeMap type_map;
+	private       Collection<Class> native_types;
+	private       boolean           is_indirect;
+	private final Element           declaration;
+	private final TypeMap           type_map;
 
-	public NativeTypeTranslator(TypeMap type_map, Declaration declaration) {
+	public NativeTypeTranslator(TypeMap type_map, Element declaration) {
 		this.declaration = declaration;
 		this.type_map = type_map;
 	}
@@ -81,8 +77,9 @@ public class NativeTypeTranslator implements TypeVisitor {
 
 	public String getSignature(final boolean skipConst) {
 		StringBuilder signature = new StringBuilder();
-		if ( !skipConst && declaration.getAnnotation(Const.class) != null )
+		if ( !skipConst && declaration.getAnnotation(Const.class) != null ) {
 			signature.append("const ");
+		}
 
 		if ( declaration.getAnnotation(PointerWrapper.class) != null ) {
 			signature.append(declaration.getAnnotation(PointerWrapper.class).value());
@@ -93,23 +90,22 @@ public class NativeTypeTranslator implements TypeVisitor {
 			signature.append(getAnnotationType().getSimpleName());
 		}
 
-		if ( is_indirect )
+		if ( is_indirect ) {
 			signature.append(" *");
+		}
 		return signature.toString();
 	}
 
 	public Class getAnnotationType() {
-		if ( native_types.size() != 1 )
-			throw new RuntimeException("Expected only one native type for declaration " + declaration +
-			                           ", but got " + native_types.size());
+		if ( native_types.size() != 1 ) {
+			throw new RuntimeException("Expected only one native type for declaration " + declaration
+			                           + ", but got " + native_types.size());
+		}
 		return native_types.iterator().next();
 	}
 
-	public void visitAnnotationType(AnnotationType t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
-
-	public void visitArrayType(ArrayType t) {
+	@Override
+	public Void visitArray(ArrayType t, Void o) {
 		final Class<?> type = Utils.getJavaType(t).getComponentType();
 
 		if ( CharSequence.class.isAssignableFrom(type) ) {
@@ -122,43 +118,47 @@ public class NativeTypeTranslator implements TypeVisitor {
 			native_types.add(type_map.getByteBufferArrayType());
 		} else if ( org.lwjgl.PointerWrapper.class.isAssignableFrom(type) ) {
 			is_indirect = false;
-		} else
+		} else {
 			throw new RuntimeException(t + " is not allowed");
+		}
+		return DEFAULT_VALUE;
 	}
 
-	public static PrimitiveType.Kind getPrimitiveKindFromBufferClass(Class c) {
-		if ( IntBuffer.class.equals(c) )
-			return PrimitiveType.Kind.INT;
-		else if ( DoubleBuffer.class.equals(c) )
-			return PrimitiveType.Kind.DOUBLE;
-		else if ( ShortBuffer.class.equals(c) )
-			return PrimitiveType.Kind.SHORT;
-		else if ( ByteBuffer.class.equals(c) || PointerBuffer.class.equals(c) )
-			return PrimitiveType.Kind.BYTE;
-		else if ( FloatBuffer.class.equals(c) )
-			return PrimitiveType.Kind.FLOAT;
-		else if ( LongBuffer.class.equals(c) )
-			return PrimitiveType.Kind.LONG;
-		else
+	public static TypeKind getPrimitiveKindFromBufferClass(Class c) {
+		if ( IntBuffer.class.equals(c) ) {
+			return TypeKind.INT;
+		} else if ( DoubleBuffer.class.equals(c) ) {
+			return TypeKind.DOUBLE;
+		} else if ( ShortBuffer.class.equals(c) ) {
+			return TypeKind.SHORT;
+		} else if ( ByteBuffer.class.equals(c) || PointerBuffer.class.equals(c) ) {
+			return TypeKind.BYTE;
+		} else if ( FloatBuffer.class.equals(c) ) {
+			return TypeKind.FLOAT;
+		} else if ( LongBuffer.class.equals(c) ) {
+			return TypeKind.LONG;
+		} else {
 			throw new RuntimeException(c + " is not allowed");
+		}
 	}
 
 	@SuppressWarnings("unchecked")
 	public static Class<? extends Annotation> getClassFromType(DeclaredType t) {
 		try {
-			return (Class<? extends Annotation>)Class.forName(t.getDeclaration().getQualifiedName());
+			return (Class<? extends Annotation>)Class.forName(t.toString());
 		} catch (ClassNotFoundException e) {
 			throw new RuntimeException(e);
 		}
 	}
 
-	private void getNativeTypeFromAnnotatedPrimitiveType(PrimitiveType.Kind kind) {
+	private void getNativeTypeFromAnnotatedPrimitiveType(TypeKind kind) {
 		native_types = translateAnnotations();
-		if ( native_types.size() == 0 )
+		if ( native_types.isEmpty() ) {
 			native_types.add(type_map.getNativeTypeFromPrimitiveType(kind));
+		}
 	}
 
-	public void visitClassType(ClassType t) {
+	private void visitClassType(DeclaredType t) {
 		is_indirect = true;
 
 		Class<?> c = getClassFromType(t);
@@ -168,53 +168,66 @@ public class NativeTypeTranslator implements TypeVisitor {
 		} else if ( Buffer.class.equals(c) ) {
 			native_types = new ArrayList<Class>();
 			native_types.add(type_map.getVoidType());
-		} else if ( Buffer.class.isAssignableFrom(c) ) {
-			PrimitiveType.Kind kind = getPrimitiveKindFromBufferClass(c);
+		} else if ( Buffer.class.isAssignableFrom(c) || PointerBuffer.class.isAssignableFrom(c) ) {
+			TypeKind kind = getPrimitiveKindFromBufferClass(c);
 			getNativeTypeFromAnnotatedPrimitiveType(kind);
-		} else if ( PointerBuffer.class.isAssignableFrom(c) ) {
-			native_types = new ArrayList<Class>();
-			native_types.add(PointerBuffer.class);
 		} else if ( org.lwjgl.PointerWrapper.class.isAssignableFrom(c) ) {
 			native_types = new ArrayList<Class>();
 			native_types.add(PointerWrapper.class);
 
 			is_indirect = false;
-		} else
+		} else {
 			throw new RuntimeException(t + " is not allowed");
+		}
 	}
 
-	public void visitPrimitiveType(PrimitiveType t) {
+	@Override
+	public Void visitPrimitive(PrimitiveType t, Void p) {
 		getNativeTypeFromAnnotatedPrimitiveType(t.getKind());
+		return DEFAULT_VALUE;
 	}
 
-	public void visitDeclaredType(DeclaredType t) {
-		throw new RuntimeException(t + " is not allowed");
+	private void visitInterfaceType(DeclaredType t) {
+		// See ARB_debug_label.glObjectPtrLabel
+		Class<?> c = getClassFromType(t);
+		if ( org.lwjgl.PointerWrapper.class.isAssignableFrom(c) ) {
+			native_types = new ArrayList<Class>();
+			native_types.add(PointerWrapper.class);
+
+			is_indirect = false;
+		} else {
+			throw new RuntimeException(t + " is not allowed");
+		}
 	}
 
-	public void visitEnumType(EnumType t) {
-		throw new RuntimeException(t + " is not allowed");
+	@Override
+	public Void visitDeclared(DeclaredType t, Void p) {
+		if ( t.asElement().getKind().isInterface() ) {
+			visitInterfaceType(t);
+		} else if ( t.asElement().getKind().isClass() ) {
+			visitClassType(t);
+		}
+		return DEFAULT_VALUE;
 	}
 
-	public void visitInterfaceType(InterfaceType t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
-
-	// Check if the annotation is itself annotated with a certain annotation type
-
+	/* Check if the annotation is itself annotated with a certain annotation type
+	 * @discuss compare (DeclaredType).getAnnotation(Class) and (Element).getAnnotation(Class), they mean different Annotation's.
+	 */
 	public static <T extends Annotation> T getAnnotation(AnnotationMirror annotation, Class<T> type) {
-		return annotation.getAnnotationType().getDeclaration().getAnnotation(type);
+		return annotation.getAnnotationType().asElement().getAnnotation(type);
 	}
 
 	private static Class translateAnnotation(AnnotationMirror annotation) {
 		NativeType native_type = getAnnotation(annotation, NativeType.class);
 		if ( native_type != null ) {
 			return getClassFromType(annotation.getAnnotationType());
-		} else
+		} else {
 			return null;
+		}
 	}
 
-	private Collection<Class> translateAnnotations() {
-		Collection<Class> result = new ArrayList<Class>();
+	private List<Class> translateAnnotations() {
+		List<Class> result = new ArrayList<Class>();
 		for ( AnnotationMirror annotation : Utils.getSortedAnnotations(declaration.getAnnotationMirrors()) ) {
 			Class translated_result = translateAnnotation(annotation);
 			if ( translated_result != null ) {
@@ -224,25 +237,13 @@ public class NativeTypeTranslator implements TypeVisitor {
 		return result;
 	}
 
-	public void visitReferenceType(ReferenceType t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
-
-	public void visitTypeMirror(TypeMirror t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
-
-	public void visitTypeVariable(TypeVariable t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
-
-	public void visitVoidType(VoidType t) {
+	@Override
+	public Void visitNoType(NoType t, Void p) {
 		native_types = translateAnnotations();
-		if ( native_types.size() == 0 )
+		if ( native_types.isEmpty() ) {
 			native_types.add(void.class);
+		}
+		return DEFAULT_VALUE;
 	}
 
-	public void visitWildcardType(WildcardType t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
 }
