@@ -38,23 +38,25 @@ package org.lwjgl.util.generator;
  * postfixes.
  *
  * @author elias_naur <elias_naur@users.sourceforge.net>
- * @version $Revision: 3412 $
- * $Id: PostfixTranslator.java 3412 2010-09-26 23:43:24Z spasi $
+ * @version $Revision$
+ * $Id$
  */
 
-import com.sun.mirror.declaration.*;
-import com.sun.mirror.type.*;
-import com.sun.mirror.util.*;
-
 import java.lang.annotation.Annotation;
 import java.nio.*;
+import javax.lang.model.element.AnnotationMirror;
+import javax.lang.model.element.Element;
+import javax.lang.model.type.DeclaredType;
+import javax.lang.model.type.PrimitiveType;
+import javax.lang.model.type.TypeKind;
+import javax.lang.model.util.SimpleTypeVisitor6;
 
-public class PostfixTranslator implements TypeVisitor {
+public class PostfixTranslator extends SimpleTypeVisitor6<Void, Void> {
 	private final StringBuilder signature = new StringBuilder();
-	private final Declaration declaration;
+	private final Element declaration;
 	private final TypeMap type_map;
 
-	public PostfixTranslator(TypeMap type_map, Declaration declaration) {
+	public PostfixTranslator(TypeMap type_map, Element declaration) {
 		this.declaration = declaration;
 		this.type_map = type_map;
 	}
@@ -63,52 +65,39 @@ public class PostfixTranslator implements TypeVisitor {
 		return signature.toString();
 	}
 
-	public void visitAnnotationType(AnnotationType t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
-
-	public void visitArrayType(ArrayType t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
-
-	private static PrimitiveType.Kind getPrimitiveKindFromBufferClass(Class c) {
-		if (IntBuffer.class.equals(c) || int.class.equals(c) )
-			return PrimitiveType.Kind.INT;
-		else if (DoubleBuffer.class.equals(c) || double.class.equals(c) )
-			return PrimitiveType.Kind.DOUBLE;
-		else if (ShortBuffer.class.equals(c) || short.class.equals(c) )
-			return PrimitiveType.Kind.SHORT;
-		else if (ByteBuffer.class.equals(c) || byte.class.equals(c) )
-			return PrimitiveType.Kind.BYTE;
-		else if (FloatBuffer.class.equals(c) || float.class.equals(c))
-			return PrimitiveType.Kind.FLOAT;
-		else if (LongBuffer.class.equals(c) || long.class.equals(c) )
-			return PrimitiveType.Kind.LONG;
+	private static TypeKind getPrimitiveKindFromBufferClass(Class c) {
+		if ( IntBuffer.class.equals(c) || int.class.equals(c) )
+			return TypeKind.INT;
+		else if ( DoubleBuffer.class.equals(c) || double.class.equals(c) )
+			return TypeKind.DOUBLE;
+		else if ( ShortBuffer.class.equals(c) || short.class.equals(c) )
+			return TypeKind.SHORT;
+		else if ( ByteBuffer.class.equals(c) || byte.class.equals(c) )
+			return TypeKind.BYTE;
+		else if ( FloatBuffer.class.equals(c) || float.class.equals(c) )
+			return TypeKind.FLOAT;
+		else if ( LongBuffer.class.equals(c) || long.class.equals(c) )
+			return TypeKind.LONG;
 		else
 			throw new RuntimeException(c + " is not allowed");
 	}
 
-	public void visitClassType(ClassType t) {
+	private void visitClassType(DeclaredType t) {
 		Class<?> c = NativeTypeTranslator.getClassFromType(t);
-		PrimitiveType.Kind kind = getPrimitiveKindFromBufferClass(c);
+		TypeKind kind = getPrimitiveKindFromBufferClass(c);
 		visitPrimitiveTypeKind(kind);
 	}
 
-	public void visitDeclaredType(DeclaredType t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
-
-	public void visitEnumType(EnumType t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
-
-	public void visitInterfaceType(InterfaceType t) {
-		throw new RuntimeException(t + " is not allowed");
+	@Override
+	public Void visitDeclared(DeclaredType t, Void o) {
+		if ( t.asElement().getKind().isClass() )
+			visitClassType(t);
+		return DEFAULT_VALUE;
 	}
 
 	private boolean translateAnnotation(AnnotationMirror annotation) {
 		NativeType native_type = NativeTypeTranslator.getAnnotation(annotation, NativeType.class);
-		if (native_type != null) {
+		if ( native_type != null ) {
 			Class<? extends Annotation> annotation_class = NativeTypeTranslator.getClassFromType(annotation.getAnnotationType());
 			signature.append(type_map.translateAnnotation(annotation_class));
 			return true;
@@ -118,26 +107,28 @@ public class PostfixTranslator implements TypeVisitor {
 
 	private boolean translateAnnotations() {
 		boolean result = false;
-		for (AnnotationMirror annotation : Utils.getSortedAnnotations(declaration.getAnnotationMirrors()))
-			if (translateAnnotation(annotation)) {
-				if (result)
+		for ( AnnotationMirror annotation : Utils.getSortedAnnotations(declaration.getAnnotationMirrors()) )
+			if ( translateAnnotation(annotation) ) {
+				if ( result )
 					throw new RuntimeException("Multiple native types");
 				result = true;
 			}
 		return result;
 	}
 
-	public void visitPrimitiveType(PrimitiveType t) {
+	@Override
+	public Void visitPrimitive(PrimitiveType t, Void o) {
 		visitPrimitiveTypeKind(t.getKind());
+		return DEFAULT_VALUE;
 	}
 
-	private void visitPrimitiveTypeKind(PrimitiveType.Kind kind) {
+	private void visitPrimitiveTypeKind(TypeKind kind) {
 		boolean annotated_translation = translateAnnotations();
-		if (annotated_translation)
+		if ( annotated_translation )
 			return;
 		// No annotation type was specified, fall back to default
 		String type;
-		switch (kind) {
+		switch ( kind ) {
 			case INT:
 				type = "i";
 				break;
@@ -161,23 +152,4 @@ public class PostfixTranslator implements TypeVisitor {
 		}
 		signature.append(type);
 	}
-
-	public void visitReferenceType(ReferenceType t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
-
-	public void visitTypeMirror(TypeMirror t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
-
-	public void visitTypeVariable(TypeVariable t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
-
-	public void visitVoidType(VoidType t) {
-	}
-
-	public void visitWildcardType(WildcardType t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
 }
\ No newline at end of file
