@@ -29,7 +29,6 @@
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
-
 package org.lwjgl.util.generator;
 
 /**
@@ -37,37 +36,41 @@ package org.lwjgl.util.generator;
  * This class generates the initNatives native function.
  *
  * @author elias_naur <elias_naur@users.sourceforge.net>
- * @version $Revision: 3418 $
- * $Id: RegisterStubsGenerator.java 3418 2010-09-28 21:11:35Z spasi $
+ * @version $Revision$ $Id$
  */
-
-import org.lwjgl.opencl.CLMem;
-
-import com.sun.mirror.declaration.*;
-import com.sun.mirror.type.*;
-
-import java.io.*;
-import java.util.*;
+import java.io.PrintWriter;
+import java.util.Arrays;
+import java.util.EnumSet;
+import java.util.Iterator;
+import java.util.List;
+import java.util.regex.Pattern;
+import javax.lang.model.element.ExecutableElement;
+import javax.lang.model.element.TypeElement;
+import javax.lang.model.element.VariableElement;
+import javax.lang.model.type.TypeMirror;
 
 public class RegisterStubsGenerator {
-	public static void generateMethodsNativeStubBind(PrintWriter writer, InterfaceDeclaration d, boolean generate_error_checks, boolean context_specific) {
-		Iterator<? extends MethodDeclaration> it = d.getMethods().iterator();
-		while (it.hasNext()) {
-			MethodDeclaration method = it.next();
+
+	public static void generateMethodsNativeStubBind(PrintWriter writer, TypeElement d, boolean generate_error_checks, boolean context_specific) {
+		Iterator<? extends ExecutableElement> it = Utils.getMethods(d).iterator();
+		while ( it.hasNext() ) {
+			ExecutableElement method = it.next();
 			Alternate alt_annotation = method.getAnnotation(Alternate.class);
-			if ( (alt_annotation != null && (!alt_annotation.nativeAlt() || alt_annotation.skipNative())) || method.getAnnotation(Reuse.class) != null )
+			if ( (alt_annotation != null && (!alt_annotation.nativeAlt() || alt_annotation.skipNative())) || method.getAnnotation(Reuse.class) != null ) {
 				continue;
+			}
 			EnumSet<Platform> platforms;
 			PlatformDependent platform_annotation = method.getAnnotation(PlatformDependent.class);
-			if (platform_annotation != null)
+			if ( platform_annotation != null ) {
 				platforms = EnumSet.copyOf(Arrays.asList(platform_annotation.value()));
-			else
+			} else {
 				platforms = EnumSet.of(Platform.ALL);
-			for (Platform platform : platforms) {
+			}
+			for ( Platform platform : platforms ) {
 				platform.printPrologue(writer);
 				boolean has_buffer_parameter = Utils.hasMethodBufferObjectParameter(method);
 				printMethodNativeStubBind(writer, d, method, platform, Mode.NORMAL, it.hasNext() || has_buffer_parameter, generate_error_checks, context_specific);
-				if (has_buffer_parameter) {
+				if ( has_buffer_parameter ) {
 					printMethodNativeStubBind(writer, d, method, platform, Mode.BUFFEROBJECT, it.hasNext(), generate_error_checks, context_specific);
 				}
 				platform.printEpilogue(writer);
@@ -76,60 +79,71 @@ public class RegisterStubsGenerator {
 		writer.println();
 	}
 
-	private static String getTypeSignature(TypeMirror type, boolean add_position_signature) {
-		SignatureTranslator v = new SignatureTranslator(add_position_signature);
-		type.accept(v);
+	private static String getTypeSignature(TypeMirror type) {
+		SignatureTranslator v = new SignatureTranslator();
+		type.accept(v, null);
 		return v.getSignature();
 	}
 
-	private static String getMethodSignature(MethodDeclaration method, Mode mode) {
-		Collection<ParameterDeclaration> params = method.getParameters();
+	private static String getMethodSignature(ExecutableElement method, Mode mode) {
+		List<? extends VariableElement> params = method.getParameters();
 		String signature = "(";
-		for (ParameterDeclaration param : params) {
-			if ( param.getAnnotation(Result.class) != null || (param.getAnnotation(Helper.class) != null && !param.getAnnotation(Helper.class).passToNative()) )
+		for ( VariableElement param : params ) {
+			if ( param.getAnnotation(Result.class) != null || (param.getAnnotation(Helper.class) != null && !param.getAnnotation(Helper.class).passToNative()) ) {
 				continue;
+			}
 
 			final Constant constant_annotation = param.getAnnotation(Constant.class);
-			if ( constant_annotation != null && constant_annotation.isNative() )
+			if ( constant_annotation != null && constant_annotation.isNative() ) {
 				continue;
+			}
 
-			if (mode == Mode.BUFFEROBJECT && param.getAnnotation(BufferObject.class) != null)
-				signature += "I";
-			else
-				signature += getTypeSignature(param.getType(), true);
+			if ( mode == Mode.BUFFEROBJECT && param.getAnnotation(BufferObject.class) != null ) {
+				signature += "J";
+			} else {
+				signature += getTypeSignature(param.asType());
+			}
 		}
 
 		final TypeMirror result_type = Utils.getMethodReturnType(method);
 		final CachedResult cached_result_annotation = method.getAnnotation(CachedResult.class);
 		final AutoSize auto_size_annotation = method.getAnnotation(AutoSize.class);
 
-		if ( Utils.getNIOBufferType(result_type) != null && (auto_size_annotation == null || !auto_size_annotation.isNative()) )
+		final boolean isNIOBuffer = Utils.getNIOBufferType(result_type) != null;
+		if ( isNIOBuffer && (auto_size_annotation == null || !auto_size_annotation.isNative()) ) {
 			signature += "J";
+		}
 
-		String result_type_signature = getTypeSignature(result_type, false);
-		if ( cached_result_annotation != null )
+		final String result_type_signature = isNIOBuffer ? "Ljava/nio/ByteBuffer;" : getTypeSignature(result_type);
+		if ( cached_result_annotation != null ) {
 			signature += result_type_signature;
+		}
 
 		signature += ")";
 		signature += result_type_signature;
 		return signature;
 	}
 
-	private static void printMethodNativeStubBind(PrintWriter writer, InterfaceDeclaration d, MethodDeclaration method, Platform platform, Mode mode, boolean has_more, boolean generate_error_checks, boolean context_specific) {
+	private static final Pattern GL_PATTERN = Pattern.compile("gl");
+
+	private static void printMethodNativeStubBind(PrintWriter writer, TypeElement d, ExecutableElement method, Platform platform, Mode mode, boolean has_more, boolean generate_error_checks, boolean context_specific) {
 		writer.print("\t\t{\"" + Utils.getSimpleNativeMethodName(method, generate_error_checks, context_specific));
-		if (mode == Mode.BUFFEROBJECT)
+		if ( mode == Mode.BUFFEROBJECT ) {
 			writer.print(Utils.BUFFER_OBJECT_METHOD_POSTFIX);
+		}
 		writer.print("\", \"" + getMethodSignature(method, mode) + "\", (void *)&");
 		writer.print(Utils.getQualifiedNativeMethodName(Utils.getQualifiedClassName(d), method, generate_error_checks, context_specific));
-		if (mode == Mode.BUFFEROBJECT)
+		if ( mode == Mode.BUFFEROBJECT ) {
 			writer.print(Utils.BUFFER_OBJECT_METHOD_POSTFIX);
+		}
 
 		final Alternate alt_annotation = method.getAnnotation(Alternate.class);
-		final String methodName = alt_annotation == null ? method.getSimpleName() : alt_annotation.value();
-		String opengl_handle_name = methodName.replaceFirst("gl", platform.getPrefix());
-		writer.print(", \"" + opengl_handle_name + "\", (void *)&" + methodName + "}");
-		if (has_more)
+		final String methodName = alt_annotation == null ? method.getSimpleName().toString() : alt_annotation.value();
+		String opengl_handle_name = GL_PATTERN.matcher(methodName).replaceFirst(platform.getPrefix());
+		writer.print(", \"" + opengl_handle_name + "\", (void *)&" + methodName + ", " + (method.getAnnotation(Optional.class) == null ? "false" : "true") + "}");
+		if ( has_more ) {
 			writer.println(",");
+		}
 	}
 
 }
