@@ -37,81 +37,89 @@ package org.lwjgl.util.generator;
  * A TypeVisitor that translates types to JNI signatures.
  *
  * @author elias_naur <elias_naur@users.sourceforge.net>
- * @version $Revision: 3443 $
- * $Id: SignatureTranslator.java 3443 2010-10-12 21:13:03Z spasi $
+ * @version $Revision$
+ * $Id$
  */
 
 import org.lwjgl.PointerBuffer;
+import org.lwjgl.PointerWrapper;
 
-import com.sun.mirror.type.*;
-import com.sun.mirror.util.*;
+import java.nio.Buffer;
+import java.nio.ByteBuffer;
+import java.util.regex.Pattern;
+import javax.lang.model.type.ArrayType;
+import javax.lang.model.type.DeclaredType;
+import javax.lang.model.type.NoType;
+import javax.lang.model.type.PrimitiveType;
+import javax.lang.model.util.SimpleTypeVisitor6;
 
-import java.nio.*;
-
-class SignatureTranslator implements TypeVisitor {
-	private final boolean add_position_signature;
+class SignatureTranslator extends SimpleTypeVisitor6<Void, Void> {
 	private final StringBuilder signature = new StringBuilder();
 
-	SignatureTranslator(boolean add_position_signature) {
-		this.add_position_signature = add_position_signature;
-	}
+	SignatureTranslator() {}
+
+	private static final Pattern DOT_PATTERN = Pattern.compile("\\.");
 
 	private static String getNativeNameFromClassName(String class_name) {
-		return class_name.replaceAll("\\.", "/");
+		return DOT_PATTERN.matcher(class_name).replaceAll("/");
 	}
 
 	public String getSignature() {
 		return signature.toString();
 	}
 
-	public void visitAnnotationType(AnnotationType t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
-
-	public void visitArrayType(ArrayType t) {
+	@Override
+	public Void visitArray(ArrayType t, Void o) {
 		final Class type = Utils.getJavaType(t.getComponentType());
 		if ( CharSequence.class.isAssignableFrom(type) )
-			signature.append("Ljava/nio/ByteBuffer;I");
+			signature.append("J");
 		else if ( Buffer.class.isAssignableFrom(type) )
 			signature.append("[Ljava/nio/ByteBuffer;");
-		else if ( org.lwjgl.PointerWrapper.class.isAssignableFrom(type) )
+		else if ( PointerWrapper.class.isAssignableFrom(type) )
 			signature.append("[L" + getNativeNameFromClassName(type.getName()) + ";");
 		else
 			throw new RuntimeException(t + " is not allowed");
+		return DEFAULT_VALUE;
+	}
+
+	private void visitClassType(DeclaredType t) {
+		Class type = NativeTypeTranslator.getClassFromType(t);
+
+		if ( PointerWrapper.class.isAssignableFrom(type) || (Utils.isAddressableType(type) && !String.class.equals(type)) )
+			signature.append("J");
+		else {
+			String type_name;
+			if ( (CharSequence.class.isAssignableFrom(type) && !String.class.equals(type)) || CharSequence[].class.isAssignableFrom(type) || PointerBuffer.class.isAssignableFrom(type) )
+				type_name = ByteBuffer.class.getName();
+			else
+				type_name = t.toString();
+
+			signature.append("L");
+			signature.append(getNativeNameFromClassName(type_name));
+			signature.append(";");
+		}
+	}
+
+	@Override
+	public Void visitDeclared(DeclaredType t, Void o) {
+		if ( t.asElement().getKind().isClass() )
+			visitClassType(t);
+		else if ( t.asElement().getKind().isInterface() )
+			visitInterfaceType(t);
+		return DEFAULT_VALUE;
+	}
+
+	private void visitInterfaceType(DeclaredType t) {
+		Class type = NativeTypeTranslator.getClassFromType(t);
+		if ( PointerWrapper.class.isAssignableFrom(type) )
+			signature.append("J");
+		else
+			throw new RuntimeException(t + " is not allowed");
 	}
 
-	public void visitClassType(ClassType t) {
-		Class type = NativeTypeTranslator.getClassFromType(t);
-		String type_name;
-		if ( (CharSequence.class.isAssignableFrom(type) && !String.class.equals(type)) || CharSequence[].class.isAssignableFrom(type) || PointerBuffer.class.isAssignableFrom(type) )
-			type_name = ByteBuffer.class.getName();
-		else if ( org.lwjgl.PointerWrapper.class.isAssignableFrom(type) ) {
-			signature.append("J");
-			return;
-		} else
-			type_name = t.getDeclaration().getQualifiedName();
-
-		signature.append("L");
-		signature.append(getNativeNameFromClassName(type_name));
-		signature.append(";");
-		if ( add_position_signature && Utils.isAddressableType(type) && !String.class.equals(type) )
-			signature.append("I");
-	}
-
-	public void visitDeclaredType(DeclaredType t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
-
-	public void visitEnumType(EnumType t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
-
-	public void visitInterfaceType(InterfaceType t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
-
-	public void visitPrimitiveType(PrimitiveType t) {
-		switch (t.getKind()) {
+	@Override
+	public Void visitPrimitive(PrimitiveType t, Void o) {
+		switch ( t.getKind() ) {
 			case BOOLEAN:
 				signature.append("Z");
 				break;
@@ -136,25 +144,13 @@ class SignatureTranslator implements TypeVisitor {
 			default:
 				throw new RuntimeException("Unsupported type " + t);
 		}
+		return DEFAULT_VALUE;
 	}
 
-	public void visitReferenceType(ReferenceType t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
-
-	public void visitTypeMirror(TypeMirror t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
-
-	public void visitTypeVariable(TypeVariable t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
-
-	public void visitVoidType(VoidType t) {
+	@Override
+	public Void visitNoType(NoType t, Void o) {
 		signature.append("V");
+		return DEFAULT_VALUE;
 	}
 
-	public void visitWildcardType(WildcardType t) {
-		throw new RuntimeException(t + " is not allowed");
-	}
 }
