@@ -37,22 +37,23 @@ package org.lwjgl.util.generator;
  * The interface to the OpenAL/OpenGL specific generator behaviour
  *
  * @author elias_naur <elias_naur@users.sourceforge.net>
- * @version $Revision: 3412 $
- * $Id: TypeMap.java 3412 2010-09-26 23:43:24Z spasi $
+ * @version $Revision$
+ * $Id$
  */
 
-import com.sun.mirror.declaration.*;
-import com.sun.mirror.type.*;
-
-import java.io.*;
+import java.io.PrintWriter;
 import java.lang.annotation.Annotation;
+import javax.lang.model.element.AnnotationMirror;
+import javax.lang.model.element.ExecutableElement;
+import javax.lang.model.type.TypeKind;
 
 public interface TypeMap {
 	void printCapabilitiesInit(PrintWriter writer);
 	String getCapabilities();
-	void printErrorCheckMethod(PrintWriter writer, MethodDeclaration method, String tabs);
+	String getAPIUtilParam(boolean comma);
+	void printErrorCheckMethod(PrintWriter writer, ExecutableElement method, String tabs);
 	String getRegisterNativesFunctionName();
-	PrimitiveType.Kind getPrimitiveTypeFromNativeType(Class<? extends Annotation> native_type);
+	TypeKind getPrimitiveTypeFromNativeType(Class<? extends Annotation> native_type);
 	String getTypedefPostfix();
 	String getFunctionPrefix();
 	void printNativeIncludes(PrintWriter writer);
@@ -62,7 +63,7 @@ public interface TypeMap {
 	Class[] getValidAnnotationTypes(Class type);
 	Class<? extends Annotation> getVoidType();
 	String translateAnnotation(Class<? extends Annotation> annotation_type);
-	Class getNativeTypeFromPrimitiveType(PrimitiveType.Kind kind);
+	Class getNativeTypeFromPrimitiveType(TypeKind kind);
 	String getAutoTypeFromAnnotation(AnnotationMirror annotation);
 	Class<? extends Annotation> getInverseType(Class<? extends Annotation> type);
 	Signedness getSignednessFromType(Class<? extends Annotation> type);
