@@ -37,23 +37,23 @@ package org.lwjgl.util.generator;
  * A TypeVisitor that generates the native typedefs.
  *
  * @author elias_naur <elias_naur@users.sourceforge.net>
- * @version $Revision: 3412 $
- * $Id: TypedefsGenerator.java 3412 2010-09-26 23:43:24Z spasi $
+ * @version $Revision$
+ * $Id$
  */
 
-import com.sun.mirror.declaration.*;
-import com.sun.mirror.type.*;
-
-import java.io.*;
-import java.util.*;
+import java.io.PrintWriter;
+import java.util.Collection;
+import javax.lang.model.element.ExecutableElement;
+import javax.lang.model.element.VariableElement;
+import javax.lang.model.type.TypeMirror;
 
 public class TypedefsGenerator {
-	private static void generateNativeTypedefs(TypeMap type_map, PrintWriter writer, MethodDeclaration method) {
+	private static void generateNativeTypedefs(TypeMap type_map, PrintWriter writer, ExecutableElement method) {
 		TypeMirror return_type = method.getReturnType();
 		writer.print("typedef ");
 		writer.print(type_map.getTypedefPostfix());
 		NativeTypeTranslator translator = new NativeTypeTranslator(type_map, method);
-		return_type.accept(translator);
+		return_type.accept(translator, null);
 		writer.print(translator.getSignature());
 		writer.print(" (");
 		writer.print(type_map.getFunctionPrefix());
@@ -62,10 +62,10 @@ public class TypedefsGenerator {
 		writer.println(");");
 	}
 
-	private static void generateNativeTypedefsParameters(TypeMap type_map, PrintWriter writer, Collection<ParameterDeclaration> params) {
-		if (params.size() > 0) {
+	private static void generateNativeTypedefsParameters(TypeMap type_map, PrintWriter writer, Collection<? extends VariableElement> params) {
+		if ( params.size() > 0 ) {
 			boolean first = true;
-			for ( ParameterDeclaration param : params ) {
+			for ( VariableElement param : params ) {
 				if ( param.getAnnotation(Helper.class) != null )
 					continue;
 
@@ -79,17 +79,17 @@ public class TypedefsGenerator {
 		}
 	}
 
-	private static void generateNativeTypedefsParameter(TypeMap type_map, PrintWriter writer, ParameterDeclaration param) {
+	private static void generateNativeTypedefsParameter(TypeMap type_map, PrintWriter writer, VariableElement param) {
 		NativeTypeTranslator translator = new NativeTypeTranslator(type_map, param);
-		param.getType().accept(translator);
+		param.asType().accept(translator, null);
 		writer.print(translator.getSignature());
-		if (param.getAnnotation(Result.class) != null || param.getAnnotation(Indirect.class) != null || param.getAnnotation(PointerArray.class) != null)
+		if ( param.getAnnotation(Result.class) != null || param.getAnnotation(Indirect.class) != null || param.getAnnotation(PointerArray.class) != null )
 			writer.print("*");
 		writer.print(" " + param.getSimpleName());
 	}
 
-	public static void generateNativeTypedefs(TypeMap type_map, PrintWriter writer, Collection<? extends MethodDeclaration> methods) {
-		for (MethodDeclaration method : methods) {
+	public static void generateNativeTypedefs(TypeMap type_map, PrintWriter writer, Collection<? extends ExecutableElement> methods) {
+		for ( ExecutableElement method : methods ) {
 			if ( method.getAnnotation(Alternate.class) == null && method.getAnnotation(Reuse.class) == null )
 				generateNativeTypedefs(type_map, writer, method);
 		}
