@@ -34,13 +34,15 @@ package org.lwjgl.util.vector;
 import java.io.Serializable;
 import java.nio.FloatBuffer;
 
+import org.lwjgl.util.vector.Vector3f;
+
 /**
  *
  * Holds a 3-tuple vector.
  *
  * @author cix_foo <cix_foo@users.sourceforge.net>
- * @version $Revision: 3418 $
- * $Id: Vector3f.java 3418 2010-09-28 21:11:35Z spasi $
+ * @version $Revision$
+ * $Id$
  */
 
 public class Vector3f extends Vector implements Serializable, ReadableVector3f, WritableVector3f {
@@ -344,4 +346,15 @@ public class Vector3f extends Vector implements Serializable, ReadableVector3f,
 	public float getZ() {
 		return z;
 	}
+	
+	public boolean equals(Object obj) {
+		if (this == obj) return true;
+		if (obj == null) return false;
+		if (getClass() != obj.getClass()) return false;
+		Vector3f other = (Vector3f)obj;
+		
+		if (x == other.x && y == other.y && z == other.z) return true;
+		
+		return false;
+	}
 }
