@@ -399,7 +399,7 @@ public interface CL10 {
 		// Create a GlobalRef to the callback object.
 		javaBeforeNative = "\t\tlong user_data = pfn_notify == null || pfn_notify.isCustom() ? 0 : CallbackUtil.createGlobalRef(pfn_notify);",
 		// Associate context with the GlobalRef, so we can delete it later.
-		javaFinally = "\t\t\tCallbackUtil.registerCallback(__result, user_data);"
+		javaFinally = "\t\t\tif ( __result != null ) __result.setContextCallback(user_data);"
 	)
 	@Check(value = "errcode_ret", canBeNull = true)
 	@PointerWrapper(value = "cl_context", params = "APIUtil.getCLPlatform(properties)")
@@ -417,13 +417,13 @@ public interface CL10 {
 		// Create a GlobalRef to the callback object.
 		javaBeforeNative = "\t\tlong user_data = pfn_notify == null || pfn_notify.isCustom() ? 0 : CallbackUtil.createGlobalRef(pfn_notify);",
 		// Associate context with the GlobalRef, so we can delete it later.
-		javaFinally = "\t\t\tCallbackUtil.registerCallback(__result, user_data);"
+		javaFinally = "\t\t\tif ( __result != null ) __result.setContextCallback(user_data);"
 	)
 	@Check(value = "errcode_ret", canBeNull = true)
 	@PointerWrapper(value = "cl_context", params = "APIUtil.getCLPlatform(properties)")
 	CLContext clCreateContext(@NullTerminated @Check("3") @Const @NativeType("cl_context_properties") PointerBuffer properties,
 	                          @Constant("1") @cl_uint int num_devices,
-	                          @Constant(value = "APIUtil.getBufferPointer().put(0, device).getBuffer(), 0", keepParam = true) CLDevice device,
+	                          @Constant(value = "APIUtil.getPointer(device)", keepParam = true) CLDevice device,
 	                          @PointerWrapper(value = "cl_create_context_callback", canBeNull = true) CLContextCallback pfn_notify,
 	                          @Constant("user_data") @PointerWrapper("void *") long user_data,
 	                          @OutParameter @Check(value = "1", canBeNull = true) @cl_int IntBuffer errcode_ret);
@@ -432,9 +432,9 @@ public interface CL10 {
 	@Code(
 		tryBlock = true,
 		// Create a GlobalRef to the callback object.
-		javaBeforeNative = "\t\tlong user_data = CallbackUtil.createGlobalRef(pfn_notify);",
+		javaBeforeNative = "\t\tlong user_data = pfn_notify == null || pfn_notify.isCustom() ? 0 : CallbackUtil.createGlobalRef(pfn_notify);",
 		// Associate context with the GlobalRef, so we can delete it later.
-		javaFinally = "\t\t\tCallbackUtil.registerCallback(__result, user_data);"
+		javaFinally = "\t\t\tif ( __result != null ) __result.setContextCallback(user_data);"
 	)
 	@Check(value = "errcode_ret", canBeNull = true)
 	@PointerWrapper(value = "cl_context", params = "APIUtil.getCLPlatform(properties)")
@@ -450,7 +450,7 @@ public interface CL10 {
 
 	@Code(
 		javaBeforeNative = "\t\tAPIUtil.releaseObjects(context);",
-		javaAfterNative = "\t\tif ( __result == CL_SUCCESS ) CallbackUtil.unregisterCallback(context);"
+		javaAfterNative = "\t\tif ( __result == CL_SUCCESS ) context.releaseImpl();"
 	)
 	@cl_int
 	int clReleaseContext(@PointerWrapper("cl_context") CLContext context);
@@ -511,7 +511,7 @@ public interface CL10 {
 	                        @PointerWrapper("cl_mem") CLMem buffer,
 	                        @cl_bool int blocking_read,
 	                        @size_t long offset,
-	                        @AutoSize("ptr") @size_t long cb,
+	                        @AutoSize("ptr") @size_t long size,
 	                        @OutParameter
 	                        @cl_byte
 	                        @cl_short
@@ -529,7 +529,7 @@ public interface CL10 {
 	                         @PointerWrapper("cl_mem") CLMem buffer,
 	                         @cl_bool int blocking_write,
 	                         @size_t long offset,
-	                         @AutoSize("ptr") @size_t long cb,
+	                         @AutoSize("ptr") @size_t long size,
 	                         @Const
 	                         @cl_byte
 	                         @cl_short
@@ -548,7 +548,7 @@ public interface CL10 {
 	                        @PointerWrapper("cl_mem") CLMem dst_buffer,
 	                        @size_t long src_offset,
 	                        @size_t long dst_offset,
-	                        @size_t long cb,
+	                        @size_t long size,
 	                        @AutoSize(value = "event_wait_list", canBeNull = true) @cl_uint int num_events_in_wait_list,
 	                        @Check(canBeNull = true) @Const @NativeType("cl_event") PointerBuffer event_wait_list,
 	                        @OutParameter @Check(value = "1", canBeNull = true) @NativeType("cl_event") PointerBuffer event);
@@ -556,13 +556,13 @@ public interface CL10 {
 	@Code(javaAfterNative = "\t\tif ( __result != null ) command_queue.registerCLEvent(event);")
 	@Check(value = "errcode_ret", canBeNull = true)
 	@cl_void
-	@AutoSize("cb")
+	@AutoSize("size")
 	ByteBuffer clEnqueueMapBuffer(@PointerWrapper("cl_command_queue") CLCommandQueue command_queue,
 	                              @PointerWrapper("cl_mem") CLMem buffer,
 	                              @cl_bool int blocking_map,
 	                              @NativeType("cl_map_flags") long map_flags,
 	                              @size_t long offset,
-	                              @size_t long cb,
+	                              @size_t long size,
 	                              @AutoSize(value = "event_wait_list", canBeNull = true) @cl_uint int num_events_in_wait_list,
 	                              @Check(canBeNull = true) @Const @NativeType("cl_event") PointerBuffer event_wait_list,
 	                              @OutParameter @Check(value = "1", canBeNull = true) @NativeType("cl_event") PointerBuffer event,
@@ -683,7 +683,7 @@ public interface CL10 {
 	@Code(javaAfterNative = "\t\tif ( __result != null ) command_queue.registerCLEvent(event);")
 	@Check(value = "errcode_ret", canBeNull = true)
 	@cl_void
-	@AutoSize(value = "extcl_CalculateImageSize(region_address, *image_row_pitch_address, image_slice_pitch == NULL ? 0 : *image_slice_pitch_address)", isNative = true)
+	@AutoSize(value = "extcl_CalculateImageSize(region_address, *image_row_pitch_address, image_slice_pitch_address == NULL ? 0 : *image_slice_pitch_address)", isNative = true)
 	ByteBuffer clEnqueueMapImage(@PointerWrapper("cl_command_queue") CLCommandQueue command_queue,
 	                             @PointerWrapper("cl_mem") CLMem image,
 	                             @cl_bool int blocking_map,
@@ -776,7 +776,7 @@ public interface CL10 {
 	CLProgram clCreateProgramWithSource3(@PointerWrapper("cl_context") CLContext context,
 	                                     @Constant("strings.length") @cl_uint int count,
 	                                     @Check("1") @PointerArray(value = "count") @Const @NativeType("cl_char") ByteBuffer[] strings,
-	                                     @Constant("APIUtil.getLengths(strings).getBuffer(), 0") @Const @NativeType("size_t") PointerBuffer lengths,
+	                                     @Constant("APIUtil.getLengths(strings)") @Const @NativeType("size_t") PointerBuffer lengths,
 	                                     @OutParameter @Check(value = "1", canBeNull = true) @cl_int IntBuffer errcode_ret);
 
 	@Alternate("clCreateProgramWithSource")
@@ -794,7 +794,7 @@ public interface CL10 {
 	CLProgram clCreateProgramWithSource4(@PointerWrapper("cl_context") CLContext context,
 	                                     @Constant("strings.length") @cl_uint int count,
 	                                     @Const @PointerArray(value = "count", lengths = "lengths") CharSequence[] strings,
-	                                     @Constant("APIUtil.getLengths(strings).getBuffer(), 0") @Const @NativeType("size_t") PointerBuffer lengths,
+	                                     @Constant("APIUtil.getLengths(strings)") @Const @NativeType("size_t") PointerBuffer lengths,
 	                                     @OutParameter @Check(value = "1", canBeNull = true) @cl_int IntBuffer errcode_ret);
 
 	// ------[ clCreateProgramWithBinary ]------
@@ -826,7 +826,7 @@ public interface CL10 {
 	CLProgram clCreateProgramWithBinary3(@PointerWrapper("cl_context") CLContext context,
 	                                     @Constant("binaries.length") @cl_uint int num_devices,
 	                                     @Check("binaries.length") @Const @NativeType("cl_device_id") PointerBuffer device_list,
-	                                     @Constant("APIUtil.getLengths(binaries).getBuffer(), 0") @Const @NativeType("size_t") PointerBuffer lengths,
+	                                     @Constant("APIUtil.getLengths(binaries)") @Const @NativeType("size_t") PointerBuffer lengths,
 	                                     @Check("1") @PointerArray("num_devices") @Const @NativeType("cl_uchar") ByteBuffer[] binaries,
 	                                     @OutParameter @Check("binaries.length") @cl_int IntBuffer binary_status,
 	                                     @OutParameter @Check(value = "1", canBeNull = true) @cl_int IntBuffer errcode_ret);
@@ -845,7 +845,8 @@ public interface CL10 {
 	@Code(
 		tryBlock = true,
 		// Create a GlobalRef to the callback object.
-		javaBeforeNative = "\t\tlong user_data = CallbackUtil.createGlobalRef(pfn_notify);",
+		javaBeforeNative = "\t\tlong user_data = CallbackUtil.createGlobalRef(pfn_notify);\n" +
+		                   "\t\tif ( pfn_notify != null ) pfn_notify.setContext(program.getParent());",
 		// Check if we need to delete the GlobalRef.
 		javaFinally = "\t\t\tCallbackUtil.checkCallback(__result, user_data);"
 	)
@@ -854,14 +855,15 @@ public interface CL10 {
 	                   @AutoSize(value = "device_list", canBeNull = true) @cl_uint int num_devices,
 	                   @Check(canBeNull = true) @Const @NativeType("cl_device_id") PointerBuffer device_list,
 	                   @Check @NullTerminated @Const @cl_char ByteBuffer options,
-	                   @PointerWrapper(value = "cl_build_program_callback", canBeNull = true) CLBuildProgramCallback pfn_notify,
+	                   @PointerWrapper(value = "cl_program_callback", canBeNull = true) CLBuildProgramCallback pfn_notify,
 	                   @Constant("user_data") @PointerWrapper("void *") long user_data);
 
 	@Alternate("clBuildProgram")
 	@Code(
 		tryBlock = true,
 		// Create a GlobalRef to the callback object.
-		javaBeforeNative = "\t\tlong user_data = CallbackUtil.createGlobalRef(pfn_notify);",
+		javaBeforeNative = "\t\tlong user_data = CallbackUtil.createGlobalRef(pfn_notify);\n" +
+		                   "\t\tif ( pfn_notify != null ) pfn_notify.setContext(program.getParent());",
 		// Check if we need to delete the GlobalRef.
 		javaFinally = "\t\t\tCallbackUtil.checkCallback(__result, user_data);"
 	)
@@ -870,23 +872,24 @@ public interface CL10 {
 	                   @AutoSize(value = "device_list", canBeNull = true) @cl_uint int num_devices,
 	                   @Check(canBeNull = true) @Const @NativeType("cl_device_id") PointerBuffer device_list,
 	                   @NullTerminated @Const CharSequence options,
-	                   @PointerWrapper(value = "cl_build_program_callback", canBeNull = true) CLBuildProgramCallback pfn_notify,
+	                   @PointerWrapper(value = "cl_program_callback", canBeNull = true) CLBuildProgramCallback pfn_notify,
 	                   @Constant("user_data") @PointerWrapper("void *") long user_data);
 
 	@Alternate("clBuildProgram")
 	@Code(
 		tryBlock = true,
 		// Create a GlobalRef to the callback object.
-		javaBeforeNative = "\t\tlong user_data = CallbackUtil.createGlobalRef(pfn_notify);",
+		javaBeforeNative = "\t\tlong user_data = CallbackUtil.createGlobalRef(pfn_notify);\n" +
+		                   "\t\tif ( pfn_notify != null ) pfn_notify.setContext(program.getParent());",
 		// Check if we need to delete the GlobalRef.
 		javaFinally = "\t\t\tCallbackUtil.checkCallback(__result, user_data);"
 	)
 	@cl_int
 	int clBuildProgram(@PointerWrapper("cl_program") CLProgram program,
 	                   @Constant("1") @cl_uint int num_devices,
-	                   @Constant(value = "APIUtil.getBufferPointer().put(0, device).getBuffer(), 0", keepParam = true) CLDevice device,
+	                   @Constant(value = "APIUtil.getPointer(device)", keepParam = true) CLDevice device,
 	                   @NullTerminated @Const CharSequence options,
-	                   @PointerWrapper(value = "cl_build_program_callback", canBeNull = true) CLBuildProgramCallback pfn_notify,
+	                   @PointerWrapper(value = "cl_program_callback", canBeNull = true) CLBuildProgramCallback pfn_notify,
 	                   @Constant("user_data") @PointerWrapper("void *") long user_data);
 
 	@cl_int
@@ -915,9 +918,10 @@ public interface CL10 {
 	@cl_int
 	int clGetProgramInfo2(@PointerWrapper("cl_program") CLProgram program,
 	                      @Constant("CL_PROGRAM_BINARIES") @NativeType("cl_program_info") int param_name,
-	                      @Constant("sizes.remainingByte()") @size_t long param_value_size,
+	                      @Constant(value = "sizes_len * sizeof(cl_uchar *)", isNative = true) @size_t long param_value_size,
+	                      @Constant("sizes.remaining()") @Helper(passToNative = true) @size_t long sizes_len,
 	                      @Helper(passToNative = true) @Check("1") @Const @NativeType("size_t") PointerBuffer sizes,
-	                      @OutParameter @Check("APIUtil.getSize(sizes)") @PointerArray(value = "param_value_size", lengths = "sizes") @NativeType("cl_uchar") ByteBuffer param_value,
+	                      @OutParameter @Check("APIUtil.getSize(sizes)") @PointerArray(value = "sizes_len", lengths = "sizes") @NativeType("cl_uchar") ByteBuffer param_value,
 	                      @OutParameter @Check(value = "1", canBeNull = true) @NativeType("size_t") PointerBuffer param_value_size_ret);
 
 	/**
@@ -936,8 +940,9 @@ public interface CL10 {
 	@cl_int
 	int clGetProgramInfo3(@PointerWrapper("cl_program") CLProgram program,
 	                      @Constant("CL_PROGRAM_BINARIES") @NativeType("cl_program_info") int param_name,
-	                      @Constant("param_value.length * PointerBuffer.getPointerSize()") @size_t long param_value_size,
-	                      @PointerArray("param_value_size") @NativeType("cl_uchar") ByteBuffer[] param_value,
+	                      @Constant(value = "param_value_len * sizeof(cl_uchar *)", isNative = true) @size_t long param_value_size,
+	                      @Constant("param_value.length") @Helper(passToNative = true) @size_t long param_value_len,
+	                      @PointerArray("param_value_len") @NativeType("cl_uchar") ByteBuffer[] param_value,
 	                      @OutParameter @Check(value = "1", canBeNull = true) @NativeType("size_t") PointerBuffer param_value_size_ret);
 
 	@cl_int
@@ -976,6 +981,7 @@ public interface CL10 {
 	@cl_int
 	int clReleaseKernel(@PointerWrapper("cl_kernel") CLKernel kernel);
 
+	@GenerateAutos
 	@cl_int
 	int clSetKernelArg(@PointerWrapper("cl_kernel") CLKernel kernel,
 	                   @cl_uint int arg_index,
@@ -994,15 +1000,7 @@ public interface CL10 {
 	                   @cl_uint int arg_index,
 	                   @Constant("PointerBuffer.getPointerSize()") @size_t long arg_size,
 	                   @Check(canBeNull = true) @Const
-	                   @Constant(value = "APIUtil.getBufferPointer().put(0, arg_value == null ? 0 : arg_value.getPointer()).getBuffer(), 0", keepParam = true) CLObject arg_value);
-
-	/** Sets the size of a __local kernel argument at the specified index. */
-	@Alternate("clSetKernelArg")
-	@cl_int
-	int clSetKernelArg2(@PointerWrapper("cl_kernel") CLKernel kernel,
-	                    @cl_uint int arg_index,
-	                    @size_t long arg_size,
-	                    @Constant("null, 0") Buffer arg_value);
+	                   @Constant(value = "APIUtil.getPointerSafe(arg_value)", keepParam = true) CLObject arg_value);
 
 	// This is used by CLKernelUtil. Assumes arg_value.position() == 0.
 
@@ -1012,7 +1010,7 @@ public interface CL10 {
 	int clSetKernelArg3(@PointerWrapper("cl_kernel") CLKernel kernel,
 	                    @cl_uint int arg_index,
 	                    @size_t long arg_size,
-	                    @Constant(value = "arg_value, 0", keepParam = true) Buffer arg_value);
+	                    @Constant(value = "MemoryUtil.getAddress0(arg_value)", keepParam = true) Buffer arg_value);
 
 	@cl_int
 	int clGetKernelInfo(@PointerWrapper("cl_kernel") CLKernel kernel,
@@ -1077,7 +1075,7 @@ public interface CL10 {
 		nativeAfterVars = "\tvoid **args_mem_loc = num_mem_objects == 0 ? NULL : (void **)malloc(num_mem_objects * sizeof(void *));",
 		nativeBeforeCall = "\t_ptr_i = 0;\n" +
 		                   "\twhile ( _ptr_i < num_mem_objects ) {\n" +
-		                   "\t\targs_mem_loc[_ptr_i] = (cl_void *)((char *)args_address + (4 + _ptr_i * (4 + sizeof(void *))));\n" +
+		                   "\t\targs_mem_loc[_ptr_i] = (cl_void *)((char *)args_address + (12 + 4 + _ptr_i * (4 + sizeof(void *))));\n" +
 		                   "\t\t_ptr_i++;\n" +
 		                   "\t}",
 		nativeAfterCall = "\tfree(args_mem_loc);"
@@ -1085,7 +1083,7 @@ public interface CL10 {
 	@cl_int
 	int clEnqueueNativeKernel(@PointerWrapper("cl_command_queue") CLCommandQueue command_queue,
 	                          @PointerWrapper("cl_native_kernel_func") CLNativeKernel user_func,
-	                          @Constant("args, 0") @cl_void ByteBuffer args,
+	                          @Constant("MemoryUtil.getAddress0(args)") @cl_void ByteBuffer args,
 	                          @AutoSize("args") @size_t long cb_args,
 	                          @Constant("mem_list == null ? 0 : mem_list.length") @cl_uint int num_mem_objects,
 	                          @Check(value = "1", canBeNull = true) @PointerArray("num_mem_objects") @Const @NativeType("cl_mem") CLMem[] mem_list,
@@ -1102,7 +1100,7 @@ public interface CL10 {
 	@Alternate("clWaitForEvents")
 	@cl_int
 	int clWaitForEvents(@Constant("1") @cl_uint int num_events,
-	                    @Constant(value = "APIUtil.getBufferPointer().put(0, event).getBuffer(), 0", keepParam = true) CLEvent event);
+	                    @Constant(value = "APIUtil.getPointer(event)", keepParam = true) CLEvent event);
 
 	@cl_int
 	int clGetEventInfo(@PointerWrapper("cl_event") CLEvent event,
@@ -1136,7 +1134,7 @@ public interface CL10 {
 	@cl_int
 	int clEnqueueWaitForEvents(@PointerWrapper("cl_command_queue") CLCommandQueue command_queue,
 	                           @Constant("1") @cl_uint int num_events,
-	                           @Constant(value = "APIUtil.getBufferPointer().put(0, event).getBuffer(), 0", keepParam = true) CLEvent event);
+	                           @Constant(value = "APIUtil.getPointer(event)", keepParam = true) CLEvent event);
 
 	@cl_int
 	int clGetEventProfilingInfo(@PointerWrapper("cl_event") CLEvent event,
@@ -1153,11 +1151,11 @@ public interface CL10 {
 
 	@Private
 	@PointerWrapper("void *")
-	CLFunctionAddress clGetExtensionFunctionAddress(@Check("1") @Const @cl_char ByteBuffer func_name);
+	CLFunctionAddress clGetExtensionFunctionAddress(@NullTerminated @Const @cl_char ByteBuffer func_name);
 
 	@Alternate("clGetExtensionFunctionAddress")
 	@Private
 	@PointerWrapper("void *")
-	CLFunctionAddress clGetExtensionFunctionAddress(CharSequence func_name);
+	CLFunctionAddress clGetExtensionFunctionAddress(@NullTerminated CharSequence func_name);
 
 }
\ No newline at end of file
