@@ -68,7 +68,7 @@ public interface ARB_occlusion_query {
 	void glDeleteQueriesARB(@AutoSize("ids") @GLsizei int n, @GLuint IntBuffer ids);
 
 	@Alternate("glDeleteQueriesARB")
-	void glDeleteQueriesARB(@Constant("1") @GLsizei int n, @Constant(value = "APIUtil.getBufferInt().put(0, id), 0", keepParam = true) int id);
+	void glDeleteQueriesARB(@Constant("1") @GLsizei int n, @Constant(value = "APIUtil.getInt(caps, id)", keepParam = true) int id);
 
 	boolean glIsQueryARB(@GLuint int id);
 
@@ -79,17 +79,25 @@ public interface ARB_occlusion_query {
 	@StripPostfix("params")
 	void glGetQueryivARB(@GLenum int target, @GLenum int pname, @OutParameter @Check("1") IntBuffer params);
 
+	/** @deprecated Will be removed in 3.0. Use {@link #glGetQueryiARB} instead. */
 	@Alternate("glGetQueryivARB")
 	@GLreturn("params")
 	@StripPostfix("params")
+	@Reuse(value = "ARBOcclusionQuery", method = "glGetQueryiARB")
+	@Deprecated
 	void glGetQueryivARB2(@GLenum int target, @GLenum int pname, @OutParameter IntBuffer params);
 
+	@Alternate("glGetQueryivARB")
+	@GLreturn("params")
+	@StripPostfix(value = "params", hasPostfix = false)
+	void glGetQueryivARB3(@GLenum int target, @GLenum int pname, @OutParameter IntBuffer params);
+
 	@StripPostfix("params")
 	void glGetQueryObjectivARB(@GLuint int id, @GLenum int pname, @OutParameter @Check("1") IntBuffer params);
 
 	@Alternate("glGetQueryObjectivARB")
 	@GLreturn("params")
-	@StripPostfix(value = "params", postfix = "v")
+	@StripPostfix(value = "params", hasPostfix = false)
 	void glGetQueryObjectivARB2(@GLuint int id, @GLenum int pname, @OutParameter IntBuffer params);
 
 	@StripPostfix("params")
@@ -97,6 +105,6 @@ public interface ARB_occlusion_query {
 
 	@Alternate("glGetQueryObjectuivARB")
 	@GLreturn("params")
-	@StripPostfix(value = "params", postfix = "v")
+	@StripPostfix(value = "params", hasPostfix = false)
 	void glGetQueryObjectuivARB2(@GLuint int id, @GLenum int pname, @OutParameter IntBuffer params);
 }
