@@ -58,16 +58,22 @@ public interface ARB_shader_subroutine {
 	/** Accepted by the &lt;pname&gt; parameter of GetActiveSubroutineUniformiv: */
 	int GL_NUM_COMPATIBLE_SUBROUTINES = 0x8E4A;
 	int GL_COMPATIBLE_SUBROUTINES = 0x8E4B;
-	int GL_UNIFORM_SIZE = GL31.GL_UNIFORM_SIZE;
-	int GL_UNIFORM_NAME_LENGTH = GL31.GL_UNIFORM_NAME_LENGTH;
 
 	@Reuse("GL40")
 	int glGetSubroutineUniformLocation(@GLuint int program, @GLenum int shadertype, @Const @NullTerminated ByteBuffer name);
 
+	@Alternate("glGetSubroutineUniformLocation")
+	@Reuse("GL40")
+	int glGetSubroutineUniformLocation(@GLuint int program, @GLenum int shadertype, @NullTerminated CharSequence name);
+
 	@Reuse("GL40")
 	@GLuint
 	int glGetSubroutineIndex(@GLuint int program, @GLenum int shadertype, @Const @NullTerminated ByteBuffer name);
 
+	@Alternate("glGetSubroutineIndex")
+	@Reuse("GL40")
+	int glGetSubroutineIndex(@GLuint int program, @GLenum int shadertype, @NullTerminated CharSequence name);
+
 	@Reuse("GL40")
 	@StripPostfix("values")
 	void glGetActiveSubroutineUniformiv(@GLuint int program, @GLenum int shadertype, @GLuint int index, @GLenum int pname,
@@ -76,7 +82,7 @@ public interface ARB_shader_subroutine {
 	@Reuse("GL40")
 	@Alternate("glGetActiveSubroutineUniformiv")
 	@GLreturn("values")
-	@StripPostfix("values")
+	@StripPostfix(value = "values", hasPostfix = false)
 	void glGetActiveSubroutineUniformiv2(@GLuint int program, @GLenum int shadertype, @GLuint int index, @GLenum int pname,
 	                                     @OutParameter IntBuffer values);
 
@@ -89,7 +95,7 @@ public interface ARB_shader_subroutine {
 	@Alternate("glGetActiveSubroutineUniformName")
 	@GLreturn(value = "name", maxLength = "bufsize")
 	void glGetActiveSubroutineUniformName2(@GLuint int program, @GLenum int shadertype, @GLuint int index, @GLsizei int bufsize,
-	                                       @OutParameter @Constant("name_length, 0") @GLsizei IntBuffer length,
+	                                       @OutParameter @Constant("MemoryUtil.getAddress0(name_length)") @GLsizei IntBuffer length,
 	                                       @OutParameter @GLchar ByteBuffer name);
 
 	@Reuse("GL40")
@@ -101,7 +107,7 @@ public interface ARB_shader_subroutine {
 	@Alternate("glGetActiveSubroutineName")
 	@GLreturn(value = "name", maxLength = "bufsize")
 	void glGetActiveSubroutineName2(@GLuint int program, @GLenum int shadertype, @GLuint int index, @GLsizei int bufsize,
-	                                @OutParameter @Constant("name_length, 0") @GLsizei IntBuffer length,
+	                                @OutParameter @Constant("MemoryUtil.getAddress0(name_length)") @GLsizei IntBuffer length,
 	                                @OutParameter @GLchar ByteBuffer name);
 
 	@Reuse("GL40")
@@ -115,7 +121,7 @@ public interface ARB_shader_subroutine {
 	@Reuse("GL40")
 	@Alternate("glGetUniformSubroutineuiv")
 	@GLreturn("params")
-	@StripPostfix("params")
+	@StripPostfix(value = "params", hasPostfix = false)
 	void glGetUniformSubroutineuiv2(@GLenum int shadertype, int location, @OutParameter @GLuint IntBuffer params);
 
 	@Reuse("GL40")
@@ -125,7 +131,7 @@ public interface ARB_shader_subroutine {
 	@Reuse("GL40")
 	@Alternate("glGetProgramStageiv")
 	@GLreturn("values")
-	@StripPostfix("values")
+	@StripPostfix(value = "values", hasPostfix = false)
 	void glGetProgramStageiv2(@GLuint int program, @GLenum int shadertype, @GLenum int pname, @OutParameter IntBuffer values);
 
 }
\ No newline at end of file
