@@ -136,7 +136,7 @@ public interface EXT_framebuffer_object {
 	void glDeleteRenderbuffersEXT(@AutoSize("renderbuffers") int n, @Const @GLuint IntBuffer renderbuffers);
 
 	@Alternate("glDeleteRenderbuffersEXT")
-	void glDeleteRenderbuffersEXT(@Constant("1") int n, @Constant(value = "APIUtil.getBufferInt().put(0, renderbuffer), 0", keepParam = true) int renderbuffer);
+	void glDeleteRenderbuffersEXT(@Constant("1") int n, @Constant(value = "APIUtil.getInt(caps, renderbuffer)", keepParam = true) int renderbuffer);
 
 	void glGenRenderbuffersEXT(@AutoSize("renderbuffers") int n, @OutParameter @GLuint IntBuffer renderbuffers);
 
@@ -149,11 +149,19 @@ public interface EXT_framebuffer_object {
 	@StripPostfix("params")
 	void glGetRenderbufferParameterivEXT(@GLenum int target, @GLenum int pname, @OutParameter @Check("4") IntBuffer params);
 
+	/** @deprecated Will be removed in 3.0. Use {@link #glGetRenderbufferParameteriEXT} instead. */
 	@Alternate("glGetRenderbufferParameterivEXT")
 	@GLreturn("params")
 	@StripPostfix("params")
+	@Reuse(value = "EXTFramebufferObject", method = "glGetRenderbufferParameteriEXT")
+	@Deprecated
 	void glGetRenderbufferParameterivEXT2(@GLenum int target, @GLenum int pname, @OutParameter IntBuffer params);
 
+	@Alternate("glGetRenderbufferParameterivEXT")
+	@GLreturn("params")
+	@StripPostfix(value = "params", hasPostfix = false)
+	void glGetRenderbufferParameterivEXT3(@GLenum int target, @GLenum int pname, @OutParameter IntBuffer params);
+
 	boolean glIsFramebufferEXT(@GLuint int framebuffer);
 
 	void glBindFramebufferEXT(@GLenum int target, @GLuint int framebuffer);
@@ -161,7 +169,7 @@ public interface EXT_framebuffer_object {
 	void glDeleteFramebuffersEXT(@AutoSize("framebuffers") int n, @Const @GLuint IntBuffer framebuffers);
 
 	@Alternate("glDeleteFramebuffersEXT")
-	void glDeleteFramebuffersEXT(@Constant("1") int n, @Constant(value = "APIUtil.getBufferInt().put(0, framebuffer), 0", keepParam = true) int framebuffer);
+	void glDeleteFramebuffersEXT(@Constant("1") int n, @Constant(value = "APIUtil.getInt(caps, framebuffer)", keepParam = true) int framebuffer);
 
 	void glGenFramebuffersEXT(@AutoSize("framebuffers") int n, @OutParameter @GLuint IntBuffer framebuffers);
 
@@ -183,10 +191,18 @@ public interface EXT_framebuffer_object {
 	@StripPostfix("params")
 	void glGetFramebufferAttachmentParameterivEXT(@GLenum int target, @GLenum int attachment, @GLenum int pname, @OutParameter @Check("4") IntBuffer params);
 
+	/** @deprecated Will be removed in 3.0. Use {@link #glGetFramebufferAttachmentParameteriEXT} instead. */
 	@Alternate("glGetFramebufferAttachmentParameterivEXT")
 	@GLreturn("params")
 	@StripPostfix("params")
+	@Reuse(value = "EXTFramebufferObject", method = "glGetFramebufferAttachmentParameteriEXT")
+	@Deprecated
 	void glGetFramebufferAttachmentParameterivEXT2(@GLenum int target, @GLenum int attachment, @GLenum int pname, @OutParameter IntBuffer params);
 
+	@Alternate("glGetFramebufferAttachmentParameterivEXT")
+	@GLreturn("params")
+	@StripPostfix(value = "params", hasPostfix = false)
+	void glGetFramebufferAttachmentParameterivEXT3(@GLenum int target, @GLenum int attachment, @GLenum int pname, @OutParameter IntBuffer params);
+
 	void glGenerateMipmapEXT(@GLenum int target);
 }
