@@ -32,7 +32,6 @@
 package org.lwjgl.opengl;
 
 import org.lwjgl.util.generator.*;
-import org.lwjgl.util.generator.Alternate;
 import org.lwjgl.util.generator.opengl.*;
 
 import java.nio.*;
@@ -41,8 +40,8 @@ import java.nio.*;
  * The core OpenGL1.1 API.
  *
  * @author cix_foo <cix_foo@users.sourceforge.net>
- * @version $Revision: 3460 $
- *          $Id: GL11.java 3460 2010-11-29 18:25:28Z spasi $
+ * @version $Revision$
+ *          $Id$
  */
 @DeprecatedGL
 public interface GL11 {
@@ -719,9 +718,9 @@ public interface GL11 {
 	void glAccum(@GLenum int op, float value);
 
 	@DeprecatedGL
-	void glAlphaFunc(@GLenum int func, @GLclampf float ref);
+	void glAlphaFunc(@GLenum int func, float ref);
 
-	void glClearColor(@GLclampf float red, @GLclampf float green, @GLclampf float blue, @GLclampf float alpha);
+	void glClearColor(float red, float green, float blue, float alpha);
 
 	@DeprecatedGL
 	void glClearAccum(float red, float green, float blue, float alpha);
@@ -743,7 +742,7 @@ public interface GL11 {
 	@DeprecatedGL
 	void glBitmap(@GLsizei int width, @GLsizei int height, float xorig, float yorig, float xmove, float ymove,
 	              @BufferObject(BufferKind.UnpackPBO)
-	              @Check("(((width + 7)/8)*height)")
+	              @Check(value = "(((width + 7)/8)*height)", canBeNull = true)
 	              @Const
 	              @GLubyte ByteBuffer bitmap);
 
@@ -755,7 +754,7 @@ public interface GL11 {
 	                          @GLuint IntBuffer textures,
 	                          @Const
 	                          @Check("textures.remaining()")
-	                          @GLclampf FloatBuffer priorities);
+	                          FloatBuffer priorities);
 
 	@DeprecatedGL
 	boolean glAreTexturesResident(@AutoSize("textures") @GLsizei int n,
@@ -776,7 +775,7 @@ public interface GL11 {
 	@NoErrorCheck
 	void glArrayElement(int i);
 
-	void glClearDepth(@GLclampd double depth);
+	void glClearDepth(double depth);
 
 	@DeprecatedGL
 	void glDeleteLists(@GLuint int list, @GLsizei int range);
@@ -784,7 +783,7 @@ public interface GL11 {
 	void glDeleteTextures(@AutoSize("textures") @GLsizei int n, @Const @GLuint IntBuffer textures);
 
 	@Alternate("glDeleteTextures")
-	void glDeleteTextures(@Constant("1") @GLsizei int n, @Constant(value = "APIUtil.getBufferInt().put(0, texture), 0", keepParam = true) int texture);
+	void glDeleteTextures(@Constant("1") @GLsizei int n, @Constant(value = "APIUtil.getInt(caps, texture)", keepParam = true) int texture);
 
 	void glCullFace(@GLenum int mode);
 
@@ -809,6 +808,14 @@ public interface GL11 {
 	                    @GLubyte
 	                    @GLbyte Buffer pointer);
 
+	@DeprecatedGL
+	@Alternate("glColorPointer")
+	void glColorPointer(int size, @GLenum int type, @GLsizei int stride,
+	                    @CachedReference
+	                    @Check
+	                    @BufferObject(BufferKind.ArrayVBO)
+	                    @Const ByteBuffer pointer);
+
 	@DeprecatedGL
 	void glColorMaterial(@GLenum int face, @GLenum int mode);
 
@@ -914,11 +921,14 @@ public interface GL11 {
 	                    @GLushort
 	                    @GLuint Buffer indices);
 
+	@Alternate("glDrawElements")
+	void glDrawElements(@GLenum int mode, @GLsizei int count, @GLenum int type, @BufferObject(BufferKind.ElementVBO) @Const @Check("count") ByteBuffer indices);
+
 	void glDrawBuffer(@GLenum int mode);
 
 	void glDrawArrays(@GLenum int mode, int first, @GLsizei int count);
 
-	void glDepthRange(@GLclampd double zNear, @GLclampd double zFar);
+	void glDepthRange(double zNear, double zFar);
 
 	void glDepthMask(boolean flag);
 
@@ -1062,7 +1072,7 @@ public interface GL11 {
 
 	@Alternate("glGetTexParameterfv")
 	@GLreturn("params")
-	@StripPostfix(value = "params", postfix = "v")
+	@StripPostfix(value = "params", hasPostfix = false)
 	void glGetTexParameterfv2(@GLenum int target, @GLenum int pname, @OutParameter FloatBuffer params);
 
 	@StripPostfix("params")
@@ -1070,7 +1080,7 @@ public interface GL11 {
 
 	@Alternate("glGetTexParameteriv")
 	@GLreturn("params")
-	@StripPostfix(value = "params", postfix = "v")
+	@StripPostfix(value = "params", hasPostfix = false)
 	void glGetTexParameteriv2(@GLenum int target, @GLenum int pname, @OutParameter IntBuffer params);
 
 	@StripPostfix("params")
@@ -1078,7 +1088,7 @@ public interface GL11 {
 
 	@Alternate("glGetTexLevelParameterfv")
 	@GLreturn("params")
-	@StripPostfix(value = "params", postfix = "v")
+	@StripPostfix(value = "params", hasPostfix = false)
 	void glGetTexLevelParameterfv2(@GLenum int target, int level, @GLenum int pname, @OutParameter FloatBuffer params);
 
 	@StripPostfix("params")
@@ -1086,7 +1096,7 @@ public interface GL11 {
 
 	@Alternate("glGetTexLevelParameteriv")
 	@GLreturn("params")
-	@StripPostfix(value = "params", postfix = "v")
+	@StripPostfix(value = "params", hasPostfix = false)
 	void glGetTexLevelParameteriv2(@GLenum int target, int level, @GLenum int pname, @OutParameter IntBuffer params);
 
 	void glGetTexImage(@GLenum int target, int level, @GLenum int format, @GLenum int type,
@@ -1105,7 +1115,7 @@ public interface GL11 {
 
 	@Alternate("glGetTexGeniv")
 	@GLreturn("params")
-	@StripPostfix(value = "params", postfix = "v")
+	@StripPostfix(value = "params", hasPostfix = false)
 	@DeprecatedGL
 	void glGetTexGeniv2(@GLenum int coord, @GLenum int pname, @OutParameter IntBuffer params);
 
@@ -1115,7 +1125,7 @@ public interface GL11 {
 
 	@Alternate("glGetTexGenfv")
 	@GLreturn("params")
-	@StripPostfix(value = "params", postfix = "v")
+	@StripPostfix(value = "params", hasPostfix = false)
 	@DeprecatedGL
 	void glGetTexGenfv2(@GLenum int coord, @GLenum int pname, @OutParameter FloatBuffer params);
 
@@ -1125,7 +1135,7 @@ public interface GL11 {
 
 	@Alternate("glGetTexGendv")
 	@GLreturn("params")
-	@StripPostfix(value = "params", postfix = "v")
+	@StripPostfix(value = "params", hasPostfix = false)
 	@DeprecatedGL
 	void glGetTexGendv2(@GLenum int coord, @GLenum int pname, @OutParameter DoubleBuffer params);
 
@@ -1134,7 +1144,7 @@ public interface GL11 {
 
 	@Alternate("glGetTexEnviv")
 	@GLreturn("params")
-	@StripPostfix(value = "params", postfix = "v")
+	@StripPostfix(value = "params", hasPostfix = false)
 	void glGetTexEnviv2(@GLenum int coord, @GLenum int pname, @OutParameter IntBuffer params);
 
 	@StripPostfix("params")
@@ -1142,7 +1152,7 @@ public interface GL11 {
 
 	@Alternate("glGetTexEnvfv")
 	@GLreturn("params")
-	@StripPostfix(value = "params", postfix = "v")
+	@StripPostfix(value = "params", hasPostfix = false)
 	void glGetTexEnvfv2(@GLenum int coord, @GLenum int pname, @OutParameter FloatBuffer params);
 
 	@Const
@@ -1304,6 +1314,14 @@ public interface GL11 {
 	                     @GLfloat
 	                     @GLdouble Buffer pointer);
 
+	@DeprecatedGL
+	@Alternate("glNormalPointer")
+	void glNormalPointer(@GLenum int type, @GLsizei int stride,
+	                     @CachedReference
+	                     @BufferObject(BufferKind.ArrayVBO)
+	                     @Check
+	                     @Const ByteBuffer pointer);
+
 	@NoErrorCheck
 	@DeprecatedGL
 	void glNormal3b(byte nx, byte ny, byte nz);
@@ -1350,6 +1368,9 @@ public interface GL11 {
 	@DeprecatedGL
 	void glRotatef(float angle, float x, float y, float z);
 
+	@DeprecatedGL
+	void glRotated(double angle, double x, double y, double z);
+
 	@DeprecatedGL
 	int glRenderMode(@GLenum int mode);
 
@@ -1440,6 +1461,14 @@ public interface GL11 {
 	                     @GLfloat
 	                     @GLdouble Buffer pointer);
 
+	@DeprecatedGL
+	@Alternate("glVertexPointer")
+	void glVertexPointer(int size, @GLenum int type, @GLsizei int stride,
+	                     @CachedReference
+	                     @BufferObject(BufferKind.ArrayVBO)
+	                     @Check
+	                     @Const ByteBuffer pointer);
+
 	@NoErrorCheck
 	@DeprecatedGL
 	void glVertex2f(float x, float y);
@@ -1574,6 +1603,14 @@ public interface GL11 {
 	                       @GLfloat
 	                       @GLdouble Buffer pointer);
 
+	@DeprecatedGL
+	@Alternate("glTexCoordPointer")
+	void glTexCoordPointer(int size, @GLenum int type, @GLsizei int stride,
+	                       @CachedReference(index = "StateTracker.getReferences(caps).glClientActiveTexture", name = "glTexCoordPointer_buffer")
+	                       @BufferObject(BufferKind.ArrayVBO)
+	                       @Check
+	                       @Const ByteBuffer pointer);
+
 	@NoErrorCheck
 	@DeprecatedGL
 	void glTexCoord1f(float s);
