@@ -41,8 +41,8 @@ import java.nio.*;
  * The core OpenGL1.3 API.
  *
  * @author cix_foo <cix_foo@users.sourceforge.net>
- * @version $Revision: 3460 $
- * $Id: GL13.java 3460 2010-11-29 18:25:28Z spasi $
+ * @version $Revision$
+ * $Id$
  */
 @DeprecatedGL
 public interface GL13 {
@@ -161,6 +161,15 @@ public interface GL13 {
 	                            @GLvoid
 	                            Buffer data);
 
+    @Alternate("glCompressedTexImage1D")
+	void glCompressedTexImage1D2(@GLenum int target, int level, @GLenum int internalformat, @GLsizei int width, int border, @GLsizei int imageSize,
+	                            @BufferObject(BufferKind.UnpackPBO)
+	                            @Check
+	                            @Const
+	                            @GLvoid
+	                            @Constant("0L")
+	                            Buffer data);
+
 	void glCompressedTexImage2D(@GLenum int target, int level, @GLenum int internalformat, @GLsizei int width, @GLsizei int height, int border, @AutoSize("data") @GLsizei int imageSize,
 	                            @BufferObject(BufferKind.UnpackPBO)
 	                            @Check
@@ -168,6 +177,15 @@ public interface GL13 {
 	                            @GLvoid
 	                            ByteBuffer data);
 
+    @Alternate("glCompressedTexImage2D")
+	void glCompressedTexImage2D2(@GLenum int target, int level, @GLenum int internalformat, @GLsizei int width, @GLsizei int height, int border, @GLsizei int imageSize,
+	                            @BufferObject(BufferKind.UnpackPBO)
+	                            @Check
+	                            @Const
+	                            @GLvoid
+	                            @Constant("0L")
+	                            ByteBuffer data);
+
 	void glCompressedTexImage3D(@GLenum int target, int level, @GLenum int internalformat, @GLsizei int width, @GLsizei int height, @GLsizei int depth, int border, @AutoSize("data") @GLsizei int imageSize,
 	                            @BufferObject(BufferKind.UnpackPBO)
 	                            @Check
@@ -175,6 +193,15 @@ public interface GL13 {
 	                            @GLvoid
 	                            ByteBuffer data);
 
+    @Alternate("glCompressedTexImage3D")
+	void glCompressedTexImage3D2(@GLenum int target, int level, @GLenum int internalformat, @GLsizei int width, @GLsizei int height, @GLsizei int depth, int border, @GLsizei int imageSize,
+	                            @BufferObject(BufferKind.UnpackPBO)
+	                            @Check
+	                            @Const
+	                            @GLvoid
+	                            @Constant("0L")
+	                            ByteBuffer data);
+
 	void glCompressedTexSubImage1D(@GLenum int target, int level, int xoffset, @GLsizei int width, @GLenum int format, @AutoSize("data") @GLsizei int imageSize,
 	                               @BufferObject(BufferKind.UnpackPBO)
 	                               @Check
@@ -253,6 +280,6 @@ public interface GL13 {
 	@DeprecatedGL
 	void glMultTransposeMatrixd(@Check("16") @Const DoubleBuffer m);
 
-	void glSampleCoverage(@GLclampf float value, boolean invert);
+	void glSampleCoverage(float value, boolean invert);
 }
 
