@@ -53,7 +53,6 @@ public interface GL33 {
 	 * parameters of BlendFuncSeparate and BlendFuncSeparatei:
 	 */
 	int GL_SRC1_COLOR = 0x88F9;
-	int GL_SRC1_ALPHA = GL15.GL_SRC1_ALPHA;
 	int GL_ONE_MINUS_SRC1_COLOR = 0x88FA;
 	int GL_ONE_MINUS_SRC1_ALPHA = 0x88FB;
 
@@ -102,7 +101,7 @@ public interface GL33 {
 	void glDeleteSamplers(@AutoSize("samplers") @GLsizei int count, @Const @GLuint IntBuffer samplers);
 
 	@Alternate("glDeleteSamplers")
-	void glDeleteSamplers(@Constant("1") @GLsizei int count, @Constant(value = "APIUtil.getBufferInt().put(0, sampler), 0", keepParam = true) int sampler);
+	void glDeleteSamplers(@Constant("1") @GLsizei int count, @Constant(value = "APIUtil.getInt(caps, sampler)", keepParam = true) int sampler);
 
 	boolean glIsSampler(@GLuint int sampler);
 
@@ -129,7 +128,7 @@ public interface GL33 {
 
 	@Alternate("glGetSamplerParameteriv")
 	@GLreturn("params")
-	@StripPostfix(value = "params", postfix = "v")
+	@StripPostfix(value = "params", hasPostfix = false)
 	void glGetSamplerParameteriv2(@GLuint int sampler, @GLenum int pname, @OutParameter IntBuffer params);
 
 	@StripPostfix("params")
@@ -137,7 +136,7 @@ public interface GL33 {
 
 	@Alternate("glGetSamplerParameterfv")
 	@GLreturn("params")
-	@StripPostfix(value = "params", postfix = "v")
+	@StripPostfix(value = "params", hasPostfix = false)
 	void glGetSamplerParameterfv2(@GLuint int sampler, @GLenum int pname, @OutParameter FloatBuffer params);
 
 	@StripPostfix("params")
@@ -145,7 +144,7 @@ public interface GL33 {
 
 	@Alternate("glGetSamplerParameterIiv")
 	@GLreturn("params")
-	@StripPostfix(value = "params", postfix = "v")
+	@StripPostfix(value = "params", hasPostfix = false)
 	void glGetSamplerParameterIiv2(@GLuint int sampler, @GLenum int pname, @OutParameter IntBuffer params);
 
 	@StripPostfix("params")
@@ -153,7 +152,7 @@ public interface GL33 {
 
 	@Alternate("glGetSamplerParameterIuiv")
 	@GLreturn("params")
-	@StripPostfix(value = "params", postfix = "v")
+	@StripPostfix(value = "params", hasPostfix = false)
 	void glGetSamplerParameterIuiv2(@GLuint int sampler, @GLenum int pname, @OutParameter IntBuffer params);
 
 	// -------------------------------------------------------------------
@@ -209,19 +208,35 @@ public interface GL33 {
 	@StripPostfix("params")
 	void glGetQueryObjecti64v(@GLuint int id, @GLenum int pname, @OutParameter @Check("1") @GLint64 LongBuffer params);
 
+	/** @deprecated Will be removed in 3.0. Use {@link #glGetQueryObjecti64} instead. */
 	@Alternate("glGetQueryObjecti64v")
 	@GLreturn("params")
 	@StripPostfix("params")
+	@Reuse(value = "GL33", method = "glGetQueryObjecti64")
+	@Deprecated
 	void glGetQueryObjecti64v2(@GLuint int id, @GLenum int pname, @OutParameter @GLint64 LongBuffer params);
 
+	@Alternate("glGetQueryObjecti64v")
+	@GLreturn("params")
+	@StripPostfix(value = "params", hasPostfix = false)
+	void glGetQueryObjecti64v3(@GLuint int id, @GLenum int pname, @OutParameter @GLint64 LongBuffer params);
+
 	@StripPostfix("params")
 	void glGetQueryObjectui64v(@GLuint int id, @GLenum int pname, @OutParameter @Check("1") @GLuint64 LongBuffer params);
 
+	/** @deprecated Will be removed in 3.0. Use {@link #glGetQueryObjectui64} instead. */
 	@Alternate("glGetQueryObjectui64v")
 	@GLreturn("params")
 	@StripPostfix("params")
+	@Reuse(value = "GL33", method = "glGetQueryObjectui64")
+	@Deprecated
 	void glGetQueryObjectui64v2(@GLuint int id, @GLenum int pname, @OutParameter @GLuint64 LongBuffer params);
 
+	@Alternate("glGetQueryObjectui64v")
+	@GLreturn("params")
+	@StripPostfix(value = "params", hasPostfix = false)
+	void glGetQueryObjectui64v3(@GLuint int id, @GLenum int pname, @OutParameter @GLuint64 LongBuffer params);
+
 	// --------------------------------------------------------------------
 	// ----------------------[ ARB_instanced_arrays ]----------------------
 	// --------------------------------------------------------------------
