@@ -46,12 +46,12 @@ public interface GL41 {
 	 * Accepted by the &lt;value&gt; parameter of GetBooleanv, GetIntegerv,
 	 * GetInteger64v, GetFloatv, and GetDoublev:
 	 */
-	int GL_SHADER_COMPILER = 0x8DFA,
-		GL_NUM_SHADER_BINARY_FORMATS = 0x8DF9,
-		GL_MAX_VERTEX_UNIFORM_VECTORS = 0x8DFB,
-		GL_MAX_VARYING_VECTORS = 0x8DFC,
-		GL_MAX_FRAGMENT_UNIFORM_VECTORS = 0x8DFD,
-		GL_IMPLEMENTATION_COLOR_READ_TYPE = 0x8B9A,
+	int GL_SHADER_COMPILER                  = 0x8DFA,
+		GL_NUM_SHADER_BINARY_FORMATS        = 0x8DF9,
+		GL_MAX_VERTEX_UNIFORM_VECTORS       = 0x8DFB,
+		GL_MAX_VARYING_VECTORS              = 0x8DFC,
+		GL_MAX_FRAGMENT_UNIFORM_VECTORS     = 0x8DFD,
+		GL_IMPLEMENTATION_COLOR_READ_TYPE   = 0x8B9A,
 		GL_IMPLEMENTATION_COLOR_READ_FORMAT = 0x8B9B;
 
 	/** Accepted by the &lt;type&gt; parameter of VertexAttribPointer: */
@@ -61,30 +61,28 @@ public interface GL41 {
 	 * Accepted by the &lt;precisiontype&gt; parameter of
 	 * GetShaderPrecisionFormat:
 	 */
-	int GL_LOW_FLOAT = 0x8DF0,
+	int GL_LOW_FLOAT    = 0x8DF0,
 		GL_MEDIUM_FLOAT = 0x8DF1,
-		GL_HIGH_FLOAT = 0x8DF2,
-		GL_LOW_INT = 0x8DF3,
-		GL_MEDIUM_INT = 0x8DF4,
-		GL_HIGH_INT = 0x8DF5;
+		GL_HIGH_FLOAT   = 0x8DF2,
+		GL_LOW_INT      = 0x8DF3,
+		GL_MEDIUM_INT   = 0x8DF4,
+		GL_HIGH_INT     = 0x8DF5;
+
+	/** Accepted by the &lt;format&gt; parameter of most commands taking sized internal formats: */
+	int GL_RGB565 = 0x8D62;
 
-	@Optional(reason = "Not exposed in ATI Catalyst 10.10c")
 	void glReleaseShaderCompiler();
 
-	@Optional(reason = "Not exposed in ATI Catalyst 10.10c")
 	void glShaderBinary(@AutoSize("shaders") @GLsizei int count, @Const @GLuint IntBuffer shaders,
 	                    @GLenum int binaryformat, @Const @GLvoid ByteBuffer binary, @AutoSize("binary") @GLsizei int length);
 
-	@Optional(reason = "Not exposed in ATI Catalyst 10.10c")
 	void glGetShaderPrecisionFormat(@GLenum int shadertype, @GLenum int precisiontype,
 	                                @OutParameter @Check("2") IntBuffer range,
 	                                @OutParameter @Check("1") IntBuffer precision);
 
-	@Optional(reason = "Not exposed in ATI Catalyst 10.10c")
-	void glDepthRangef(@GLclampf float n, @GLclampf float f);
+	void glDepthRangef(float n, float f);
 
-	@Optional(reason = "Not exposed in ATI Catalyst 10.10c")
-	void glClearDepthf(@GLclampf float d);
+	void glClearDepthf(float d);
 
 	// ----------------------------------------------------------------------
 	// ----------------------[ ARB_get_program_binary ]----------------------
@@ -104,7 +102,7 @@ public interface GL41 {
 	 * GetInteger64v, GetFloatv and GetDoublev:
 	 */
 	int GL_NUM_PROGRAM_BINARY_FORMATS = 0x87FE,
-		GL_PROGRAM_BINARY_FORMATS = 0x87FF;
+		GL_PROGRAM_BINARY_FORMATS     = 0x87FF;
 
 	void glGetProgramBinary(@GLuint int program, @AutoSize("binary") @GLsizei int bufSize,
 	                        @Check(value = "1", canBeNull = true) @GLsizei IntBuffer length,
@@ -120,12 +118,12 @@ public interface GL41 {
 	// ---------------------------------------------------------------------------
 
 	/** Accepted by &lt;stages&gt; parameter to UseProgramStages: */
-	int GL_VERTEX_SHADER_BIT = 0x00000001,
-		GL_FRAGMENT_SHADER_BIT = 0x00000002,
-		GL_GEOMETRY_SHADER_BIT = 0x00000004,
-		GL_TESS_CONTROL_SHADER_BIT = 0x00000008,
+	int GL_VERTEX_SHADER_BIT          = 0x00000001,
+		GL_FRAGMENT_SHADER_BIT        = 0x00000002,
+		GL_GEOMETRY_SHADER_BIT        = 0x00000004,
+		GL_TESS_CONTROL_SHADER_BIT    = 0x00000008,
 		GL_TESS_EVALUATION_SHADER_BIT = 0x00000010,
-		GL_ALL_SHADER_BITS = 0xFFFFFFFF;
+		GL_ALL_SHADER_BITS            = 0xFFFFFFFF;
 
 	/**
 	 * Accepted by the &lt;pname&gt; parameter of ProgramParameteri and
@@ -146,27 +144,39 @@ public interface GL41 {
 
 	void glActiveShaderProgram(@GLuint int pipeline, @GLuint int program);
 
-	@StripPostfix(value = "strings", postfix = "v")
+	/** Single null-terminated source code string. */
+	@StripPostfix(value = "string", hasPostfix = false)
 	@GLuint
-	int glCreateShaderProgramv(@GLenum int type, @GLsizei int count, @Check @Const @Indirect @GLchar ByteBuffer strings);
+	int glCreateShaderProgramv(@GLenum int type, @Constant("1") @GLsizei int count, @NullTerminated @Check @Const @Indirect @GLchar ByteBuffer string);
+
+	/** Multiple null-terminated source code strings, one after the other. */
+	@Alternate(value = "glCreateShaderProgramv", nativeAlt = true)
+	@StripPostfix(value = "strings", hasPostfix = false)
+	@GLuint
+	int glCreateShaderProgramv2(@GLenum int type, @GLsizei int count, @NullTerminated("count") @Check @Const @Indirect @GLchar @PointerArray("count") ByteBuffer strings);
+
+	@Alternate(value = "glCreateShaderProgramv", nativeAlt = true)
+	@StripPostfix(value = "strings", hasPostfix = false)
+	@GLuint
+	int glCreateShaderProgramv3(@GLenum int type, @Constant("strings.length") @GLsizei int count, @NullTerminated @Check("1") @PointerArray(value = "count") @Const @NativeType("GLchar") ByteBuffer[] strings);
 
 	@Alternate("glCreateShaderProgramv")
-	@StripPostfix(value = "string", postfix = "v")
+	@StripPostfix(value = "string", hasPostfix = false)
 	@GLuint
 	int glCreateShaderProgramv(@GLenum int type, @Constant("1") @GLsizei int count, @NullTerminated CharSequence string);
 
-	@Alternate("glCreateShaderProgramv")
-	@StripPostfix(value = "strings", postfix = "v")
+	@Alternate(value = "glCreateShaderProgramv", nativeAlt = true, skipNative = true)
+	@StripPostfix(value = "strings", hasPostfix = false)
 	@GLuint
-	int glCreateShaderProgramv(@GLenum int type, @Constant("strings.length") @GLsizei int count,
-	                           @Const @NullTerminated @PointerArray(value = "count") CharSequence[] strings);
+	int glCreateShaderProgramv2(@GLenum int type, @Constant("strings.length") @GLsizei int count,
+	                            @Const @NullTerminated @PointerArray(value = "count") CharSequence[] strings);
 
 	void glBindProgramPipeline(@GLuint int pipeline);
 
 	void glDeleteProgramPipelines(@AutoSize("pipelines") @GLsizei int n, @Const @GLuint IntBuffer pipelines);
 
 	@Alternate("glDeleteProgramPipelines")
-	void glDeleteProgramPipelines(@Constant("1") @GLsizei int n, @Constant(value = "APIUtil.getBufferInt().put(0, pipeline), 0", keepParam = true) int pipeline);
+	void glDeleteProgramPipelines(@Constant("1") @GLsizei int n, @Constant(value = "APIUtil.getInt(caps, pipeline)", keepParam = true) int pipeline);
 
 	void glGenProgramPipelines(@AutoSize("pipelines") @GLsizei int n, @OutParameter @GLuint IntBuffer pipelines);
 
@@ -181,7 +191,7 @@ public interface GL41 {
 
 	@Alternate("glGetProgramPipelineiv")
 	@GLreturn("params")
-	@StripPostfix("params")
+	@StripPostfix(value = "params", hasPostfix = false)
 	void glGetProgramPipelineiv2(@GLuint int pipeline, @GLenum int pname, @OutParameter IntBuffer params);
 
 	void glProgramUniform1i(@GLuint int program, int location, int v0);
@@ -339,62 +349,38 @@ public interface GL41 {
 	@Alternate("glGetProgramPipelineInfoLog")
 	@GLreturn(value = "infoLog", maxLength = "bufSize")
 	void glGetProgramPipelineInfoLog2(@GLuint int pipeline, @GLsizei int bufSize,
-	                                  @OutParameter @GLsizei @Constant("infoLog_length, 0") IntBuffer length,
+	                                  @OutParameter @GLsizei @Constant("MemoryUtil.getAddress0(infoLog_length)") IntBuffer length,
 	                                  @OutParameter @GLchar ByteBuffer infoLog);
 
 	// -----------------------------------------------------------------------
 	// ----------------------[ ARB_vertex_attrib_64bit ]----------------------
 	// -----------------------------------------------------------------------
 
-	/** Returned in the &lt;type&gt; parameter of GetActiveAttrib: */
-	int GL_DOUBLE_VEC2 = 0x8FFC;
-	int GL_DOUBLE_VEC3 = 0x8FFD;
-	int GL_DOUBLE_VEC4 = 0x8FFE;
-	int GL_DOUBLE_MAT2 = 0x8F46;
-	int GL_DOUBLE_MAT3 = 0x8F47;
-	int GL_DOUBLE_MAT4 = 0x8F48;
-	int GL_DOUBLE_MAT2x3 = 0x8F49;
-	int GL_DOUBLE_MAT2x4 = 0x8F4A;
-	int GL_DOUBLE_MAT3x2 = 0x8F4B;
-	int GL_DOUBLE_MAT3x4 = 0x8F4C;
-	int GL_DOUBLE_MAT4x2 = 0x8F4D;
-	int GL_DOUBLE_MAT4x3 = 0x8F4E;
-
-	@Optional(reason = "Not exposed in ATI Catalyst 10.10c")
 	void glVertexAttribL1d(@GLuint int index, double x);
 
-	@Optional(reason = "Not exposed in ATI Catalyst 10.10c")
 	void glVertexAttribL2d(@GLuint int index, double x, double y);
 
-	@Optional(reason = "Not exposed in ATI Catalyst 10.10c")
 	void glVertexAttribL3d(@GLuint int index, double x, double y, double z);
 
-	@Optional(reason = "Not exposed in ATI Catalyst 10.10c")
 	void glVertexAttribL4d(@GLuint int index, double x, double y, double z, double w);
 
-	@Optional(reason = "Not exposed in ATI Catalyst 10.10c")
 	@StripPostfix("v")
 	void glVertexAttribL1dv(@GLuint int index, @Const @Check("1") DoubleBuffer v);
 
-	@Optional(reason = "Not exposed in ATI Catalyst 10.10c")
 	@StripPostfix("v")
 	void glVertexAttribL2dv(@GLuint int index, @Const @Check("2") DoubleBuffer v);
 
-	@Optional(reason = "Not exposed in ATI Catalyst 10.10c")
 	@StripPostfix("v")
 	void glVertexAttribL3dv(@GLuint int index, @Const @Check("3") DoubleBuffer v);
 
-	@Optional(reason = "Not exposed in ATI Catalyst 10.10c")
 	@StripPostfix("v")
 	void glVertexAttribL4dv(@GLuint int index, @Const @Check("4") DoubleBuffer v);
 
-	@Optional(reason = "Not exposed in ATI Catalyst 10.10c")
 	void glVertexAttribLPointer(@GLuint int index, int size, @Constant("GL11.GL_DOUBLE") @GLenum int type, @GLsizei int stride,
 	                            @CachedReference(index = "index", name = "glVertexAttribPointer_buffer")
 	                            @BufferObject(BufferKind.ArrayVBO)
 	                            @Check @Const @GLdouble Buffer pointer);
 
-	@Optional(reason = "Not exposed in ATI Catalyst 10.10c")
 	@StripPostfix("params")
 	void glGetVertexAttribLdv(@GLuint int index, @GLenum int pname, @OutParameter @Check("4") DoubleBuffer params);
 
@@ -406,32 +392,17 @@ public interface GL41 {
 	 * Accepted by the &lt;pname&gt; parameter of GetBooleanv, GetIntegerv, GetFloatv,
 	 * GetDoublev and GetInteger64v:
 	 */
-	int GL_MAX_VIEWPORTS = 0x825B,
-		GL_VIEWPORT_SUBPIXEL_BITS = 0x825C,
-		GL_VIEWPORT_BOUNDS_RANGE = 0x825D,
-		GL_LAYER_PROVOKING_VERTEX = 0x825E,
+	int GL_MAX_VIEWPORTS                   = 0x825B,
+		GL_VIEWPORT_SUBPIXEL_BITS          = 0x825C,
+		GL_VIEWPORT_BOUNDS_RANGE           = 0x825D,
+		GL_LAYER_PROVOKING_VERTEX          = 0x825E,
 		GL_VIEWPORT_INDEX_PROVOKING_VERTEX = 0x825F;
 
-	/** Accepted by the &lt;pname&gt; parameter of GetIntegeri_v: */
-	int GL_SCISSOR_BOX = 0x0C10;
-
-	/** Accepted by the &lt;pname&gt; parameter of GetFloati_v: */
-	int GL_VIEWPORT = 0x0BA2;
-
-	/** Accepted by the &lt;pname&gt; parameter of GetDoublei_v: */
-	int GL_DEPTH_RANGE = 0x0B70;
-
-	/** Accepted by the &lt;pname&gt; parameter of Enablei, Disablei, and IsEnabledi: */
-	int GL_SCISSOR_TEST = 0x0C11;
-
 	/**
 	 * Returned in the &lt;data&gt; parameter from a Get query with a &lt;pname&gt; of
 	 * LAYER_PROVOKING_VERTEX or VIEWPORT_INDEX_PROVOKING_VERTEX:
 	 */
-	int GL_FIRST_VERTEX_CONVENTION = 0x8E4D,
-		GL_LAST_VERTEX_CONVENTION = 0x8E4E,
-		GL_PROVOKING_VERTEX = 0x8E4F,
-		GL_UNDEFINED_VERTEX = 0x8260;
+	int GL_UNDEFINED_VERTEX = 0x8260;
 
 	@StripPostfix("v")
 	void glViewportArrayv(@GLuint int first, @AutoSize(value = "v", expression = " >> 2") @GLsizei int count, @Const FloatBuffer v);
@@ -450,9 +421,9 @@ public interface GL41 {
 	void glScissorIndexedv(@GLuint int index, @Check("4") @Const IntBuffer v);
 
 	@StripPostfix("v")
-	void glDepthRangeArrayv(@GLuint int first, @AutoSize(value = "v", expression = " >> 1") @GLsizei int count, @Const @GLclampd DoubleBuffer v);
+	void glDepthRangeArrayv(@GLuint int first, @AutoSize(value = "v", expression = " >> 1") @GLsizei int count, @Const DoubleBuffer v);
 
-	void glDepthRangeIndexed(@GLuint int index, @GLclampd double n, @GLclampd double f);
+	void glDepthRangeIndexed(@GLuint int index, double n, double f);
 
 	@StripPostfix("data")
 	void glGetFloati_v(@GLenum int target, @GLuint int index, @Check @OutParameter FloatBuffer data);
