@@ -127,59 +127,59 @@ public interface NV_gpu_shader5 {
 
 	// -------------
 
-	@Dependent("EXT_direct_state_access")
+	@Dependent("GL_EXT_direct_state_access")
 	void glProgramUniform1i64NV(@GLuint int program, int location, @GLint64EXT long x);
 
-	@Dependent("EXT_direct_state_access")
+	@Dependent("GL_EXT_direct_state_access")
 	void glProgramUniform2i64NV(@GLuint int program, int location, @GLint64EXT long x, @GLint64EXT long y);
 
-	@Dependent("EXT_direct_state_access")
+	@Dependent("GL_EXT_direct_state_access")
 	void glProgramUniform3i64NV(@GLuint int program, int location, @GLint64EXT long x, @GLint64EXT long y, @GLint64EXT long z);
 
-	@Dependent("EXT_direct_state_access")
+	@Dependent("GL_EXT_direct_state_access")
 	void glProgramUniform4i64NV(@GLuint int program, int location, @GLint64EXT long x, @GLint64EXT long y, @GLint64EXT long z, @GLint64EXT long w);
 
-	@Dependent("EXT_direct_state_access")
+	@Dependent("GL_EXT_direct_state_access")
 	@StripPostfix("value")
 	void glProgramUniform1i64vNV(@GLuint int program, int location, @AutoSize("value") @GLsizei int count, @Const @GLint64EXT LongBuffer value);
 
-	@Dependent("EXT_direct_state_access")
+	@Dependent("GL_EXT_direct_state_access")
 	@StripPostfix("value")
 	void glProgramUniform2i64vNV(@GLuint int program, int location, @AutoSize(value = "value", expression = " >> 1") @GLsizei int count, @Const @GLint64EXT LongBuffer value);
 
-	@Dependent("EXT_direct_state_access")
+	@Dependent("GL_EXT_direct_state_access")
 	@StripPostfix("value")
 	void glProgramUniform3i64vNV(@GLuint int program, int location, @AutoSize(value = "value", expression = " / 3") @GLsizei int count, @Const @GLint64EXT LongBuffer value);
 
-	@Dependent("EXT_direct_state_access")
+	@Dependent("GL_EXT_direct_state_access")
 	@StripPostfix("value")
 	void glProgramUniform4i64vNV(@GLuint int program, int location, @AutoSize(value = "value", expression = " >> 2") @GLsizei int count, @Const @GLint64EXT LongBuffer value);
 
-	@Dependent("EXT_direct_state_access")
+	@Dependent("GL_EXT_direct_state_access")
 	void glProgramUniform1ui64NV(@GLuint int program, int location, @GLuint64EXT long x);
 
-	@Dependent("EXT_direct_state_access")
+	@Dependent("GL_EXT_direct_state_access")
 	void glProgramUniform2ui64NV(@GLuint int program, int location, @GLuint64EXT long x, @GLuint64EXT long y);
 
-	@Dependent("EXT_direct_state_access")
+	@Dependent("GL_EXT_direct_state_access")
 	void glProgramUniform3ui64NV(@GLuint int program, int location, @GLuint64EXT long x, @GLuint64EXT long y, @GLuint64EXT long z);
 
-	@Dependent("EXT_direct_state_access")
+	@Dependent("GL_EXT_direct_state_access")
 	void glProgramUniform4ui64NV(@GLuint int program, int location, @GLuint64EXT long x, @GLuint64EXT long y, @GLuint64EXT long z, @GLuint64EXT long w);
 
-	@Dependent("EXT_direct_state_access")
+	@Dependent("GL_EXT_direct_state_access")
 	@StripPostfix("value")
 	void glProgramUniform1ui64vNV(@GLuint int program, int location, @AutoSize("value") @GLsizei int count, @Const @GLuint64EXT LongBuffer value);
 
-	@Dependent("EXT_direct_state_access")
+	@Dependent("GL_EXT_direct_state_access")
 	@StripPostfix("value")
 	void glProgramUniform2ui64vNV(@GLuint int program, int location, @AutoSize(value = "value", expression = " >> 1") @GLsizei int count, @Const @GLuint64EXT LongBuffer value);
 
-	@Dependent("EXT_direct_state_access")
+	@Dependent("GL_EXT_direct_state_access")
 	@StripPostfix("value")
 	void glProgramUniform3ui64vNV(@GLuint int program, int location, @AutoSize(value = "value", expression = " / 3") @GLsizei int count, @Const @GLuint64EXT LongBuffer value);
 
-	@Dependent("EXT_direct_state_access")
+	@Dependent("GL_EXT_direct_state_access")
 	@StripPostfix("value")
 	void glProgramUniform4ui64vNV(@GLuint int program, int location, @AutoSize(value = "value", expression = " >> 2") @GLsizei int count, @Const @GLuint64EXT LongBuffer value);
 
